@@ -1,9 +1,13 @@
 #ifndef TLPCAMERA_H
 #define TLPCAMERA_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <tulip/Coord.h>
 
-class Camera {
+class TLP_GL_SCOPE Camera {
  public:
   Coord center,eyes,up;
   double zoomFactor;
