@@ -11,7 +11,7 @@ struct GlLines
 {
   //Curves types: linear, bezier, spline order 3, spline order 4
   enum InterpolationMethod {LINEAR=0, BEZIER, SPLINE3, SPLINE4};
-  enum StippleType {PLAIN=0, DOT, DASHED, ALTERNATE};
+  enum StippleType {TLP_PLAIN=0, TLP_DOT, TLP_DASHED, TLP_ALTERNATE};
   
   static void glDrawPoint(const Coord &p);
 
