@@ -2,6 +2,7 @@
 #define _HLINE_H_
 
 #include "Frame.h"
+class Renderer;
 
 const unsigned char ROUGE=255;
 const unsigned char VERT=255;
@@ -10,8 +11,9 @@ const unsigned char BLEU=255;
 class Hline : public Frame{
 
   unsigned char couleur[3]; // couleur que prend le tracé
+  const Renderer &renderer;
  public:
-  Hline(){couleur[0] = ROUGE; couleur[1] = VERT; couleur[2] = BLEU;}
+  Hline(const Renderer &renderer):renderer(renderer) {couleur[0] = ROUGE; couleur[1] = VERT; couleur[2] = BLEU;}
   virtual ~Hline(){}
   void draw(float w_max, float& w) const;
   void getBoundingBox(float w_max, float& h, float& w) const;
