@@ -3,6 +3,7 @@
 
 #include <string>
 #include <libxml/parser.h>
+#include <tulip/tulipconf.h>
 #include <tulip/Context.h>
 #include <tulip/Fonts.h>
 
@@ -13,7 +14,7 @@ class Document;
 class Parser;
 
 
-class TextRenderer{
+class TLP_GL_SCOPE TextRenderer{
 
  public:
   TextRenderer();
@@ -22,6 +23,7 @@ class TextRenderer{
   void getBoundingBox(float w_max, float& h, float& w) const;
   void setString(std::string str, TextMode mode);
   void setContext(std::string str, int s, unsigned char r, unsigned char v, unsigned char b);
+  void setColor(unsigned char r, unsigned char g, unsigned char b);
   void setMode(FontMode  m);
 
  private:  
