@@ -45,17 +45,16 @@ using namespace std;
 //====================================================
 #ifdef _WIN32 
 #ifdef DLL_EXPORT
-TemplateFactory<GlyphFactory,Glyph,GlyphContext *> GlGraph::glyphFactory;
+TemplateFactory<GlyphFactory,Glyph,GlyphContext *> *GlGraph::glyphFactory;
 stdext::hash_map<int,std::string>  GlGraph::idToName;
 stdext::hash_map<std::string, int> GlGraph::nameToId;
 #endif
 #else
-TemplateFactory<GlyphFactory,Glyph,GlyphContext *> GlGraph::glyphFactory;
+TemplateFactory<GlyphFactory,Glyph,GlyphContext *> *GlGraph::glyphFactory;
 stdext::hash_map<int,std::string>  GlGraph::idToName;
 stdext::hash_map<std::string, int> GlGraph::nameToId;
 #endif
-
-
+//====================================================
 std::string GlGraph::glyphName(int id) {
   if (idToName.find(id)!=idToName.end())
     return idToName[id];
@@ -76,14 +75,45 @@ int GlGraph::glyphId(std::string name) {
   }
 }
 //====================================================
+const int GlGraph::edgeShapesCount = 3;
+int GlGraph::edgeShapeIds[GlGraph::edgeShapesCount] =
+  {BEZIERSHAPE, POLYLINESHAPE, SPLINESHAPE};
+std::string GlGraph::edgeShapeName(int id) {
+  switch(id) {
+  case POLYLINESHAPE:
+    return std::string("Polyline");
+  case BEZIERSHAPE:
+    return std::string("Bezier Curve");
+  case SPLINESHAPE:
+    return std::string("Spline Curve");
+  defaut:
+    cerr << __PRETTY_FUNCTION__ << endl;
+    cerr << "Invalid edge shape id" << endl;
+    return std::string("invalid shape id");
+  }
+}
+//====================================================
+int GlGraph::edgeShapeId(std::string name) {
+  if (name == edgeShapeName(POLYLINESHAPE))
+    return POLYLINESHAPE;
+  if (name == edgeShapeName(BEZIERSHAPE))
+    return BEZIERSHAPE;
+  if (name == edgeShapeName(SPLINESHAPE))
+    return SPLINESHAPE;
+  cerr << __PRETTY_FUNCTION__ << endl;
+  cerr << "Invalid edge shape name" << endl;
+  return -1;
+}
+//====================================================
 void GlGraph::loadPlugins(string dir, PluginLoader *plug) {
-  GlGraph::glyphFactory.load(dir + "glyph", "Glyph", plug);
+  initFactory();
+  GlGraph::glyphFactory->load(dir + "glyph", "Glyph", plug);
   idToName.clear();
   nameToId.clear();
-  Iterator<string> *itS=glyphFactory.availablePlugins();
+  Iterator<string> *itS=glyphFactory->availablePlugins();
   while (itS->hasNext()) {
   	string pluginName=itS->next();
-    int pluginId=glyphFactory.objMap[pluginName]->getId();
+    int pluginId=glyphFactory->objMap[pluginName]->getId();
     idToName[pluginId]=pluginName;
     nameToId[pluginName]=pluginId;
   } delete itS;
@@ -104,12 +134,7 @@ void GlGraph::loadPlugins(PluginLoader *plug) {
     loadPlugins(string(begin,end)+"/",plug);
 }
 //====================================================
-//dummy constructor made private since we want to forbid calling copy constructor
-GlGraph::GlGraph(const GlGraph &) { 
-}
-
-GlGraph::GlGraph(GlGraphStrategy &strategy):
-  strategy(&strategy),
+GlGraph::GlGraph():
   _superGraph(0),
   backgroundColor(65,65,65),
   _viewArrow(false), _viewLabel(false),
@@ -137,14 +162,14 @@ GlGraph::GlGraph(GlGraphStrategy &strategy):
   labelsBorder(2),
   layoutName("viewLayout")
 {
+  initFactory();
   initProxies();
   TRACE_EXEC();
   fontsPath = tlp::TulipLibDir + "tlp/bitmaps/";
   fontRenderer = new TextRenderer();
 }
-
-GlGraph::GlGraph(GlGraphStrategy &strategy, const GlGraph &g) :
-  strategy(&strategy),
+//====================================================
+GlGraph::GlGraph(const GlGraph &g) :
   _superGraph(g._superGraph),
   backgroundColor(g.backgroundColor),
   _viewArrow(g._viewArrow), _viewLabel(g._viewLabel),
@@ -173,16 +198,19 @@ GlGraph::GlGraph(GlGraphStrategy &strategy, const GlGraph &g) :
   winH(g.winH), winW(g.winW),
   winX(g.winX), winY(g.winY),
   labelsBorder(g.labelsBorder) {
+  initFactory();
   initProxies();
-  for (int i=0; i<4; ++i) vp[i] = g.vp[i];
+  for (int i=0; i<4; ++i) viewportArray[i] = g.viewportArray[i];
   _superGraph->addObserver(this);
   if (isViewStrahler()) {
     buildOrderedList();
   }
+  fontsPath = tlp::TulipLibDir + "tlp/bitmaps/";
   fontRenderer = new TextRenderer();
 }
 //====================================================
 GlGraph::~GlGraph() {
+  //  cerr << __PRETTY_FUNCTION__ << endl;
   notifyDestroy(this);
   removeObservers();
   if(_superGraph != 0)
@@ -206,13 +234,13 @@ void GlGraph::centerScene() {
 void GlGraph::changeViewport( unsigned int x, unsigned int y, unsigned int w, unsigned int h ) {
   //  cerr << __PRETTY_FUNCTION__ << endl;
   TRACE_EXEC();
-  strategy->MakeCurrent();
+  makeCurrent();
   winX=x;
   winY=y;
   winH=h;
   winW=w;
   glViewport(winX,winY,winW,winH);
-  glGetIntegerv(GL_VIEWPORT, vp);
+  glGetIntegerv(GL_VIEWPORT, viewportArray);
 }
 //====================================================
 SuperGraph* GlGraph::getSuperGraph() const {
@@ -223,7 +251,7 @@ void GlGraph::setSuperGraph(SuperGraph *superGraph) {
   //   cerr << __PRETTY_FUNCTION__ << endl;
   if ( superGraph == _superGraph ) return;
   TRACE_EXEC();
-  strategy->timerStop();
+  timerStop();
   if (_superGraph!=0)
     _superGraph->removeObserver(this);
   if (superGraph!=_superGraph)
@@ -241,8 +269,9 @@ void GlGraph::setSuperGraph(SuperGraph *superGraph) {
 void GlGraph::draw() {
   //cerr << __PRETTY_FUNCTION__ << endl;
   Observable::holdObservers();
-  strategy->timerStop();
-  strategy->MakeCurrent();
+  timerStop();
+  makeCurrent();
+  nodesRenderedAsPoint.setAll(false);
   occlusionTest.reset();
   initGlParameter();
   initLights();
@@ -256,21 +285,20 @@ void GlGraph::draw() {
   }
   initIterators();
   if (!_incrementalRendering) {
+    drawNodes(_superGraph->numberOfNodes(),drawNodesIterator);
     if (_displayEdges) 
       drawEdges(_superGraph->numberOfEdges(),drawEdgesIterator);
-    drawNodes(_superGraph->numberOfNodes(),drawNodesIterator);
     if (isViewLabel()) {
       drawNodeLabels(_superGraph->numberOfNodes(),drawSelectedLabelsIterator,true);
       drawEdgeLabels(_superGraph->numberOfEdges(),drawEdgeSelectedLabelsIterator,true);
       drawNodeLabels(_superGraph->numberOfNodes(),drawLabelsIterator,false);
       drawEdgeLabels(_superGraph->numberOfEdges(),drawEdgeLabelsIterator,false);
     }
-    glFinish();
   }
   else {
-    strategy->timerStart(0);
+    timerStart(0);
   }
-  strategy->mPaint(this);
+  mPaint();
   notifyDraw(this);
   Observable::unholdObservers();
  }
@@ -283,7 +311,7 @@ bool GlGraph::drawPart() {
   //  cerr << __PRETTY_FUNCTION__ << endl;
   if (_superGraph==0) return true;
   Observable::holdObservers();
-  strategy->MakeCurrent();
+  makeCurrent();
   initLights();
   initProjection();
   initModelView();
@@ -293,14 +321,6 @@ bool GlGraph::drawPart() {
   startTime = getTime();
   unsigned int elementToDraw = nbElementsFrame.get(currentFrame);
   switch (drawState) {
-  case DRAWEDGE :
-   if (!_displayEdges || !drawEdgesIterator->hasNext()) 
-      drawState++;
-    else {
-      elementToDraw -= drawEdges(elementToDraw, drawEdgesIterator);
-      if (drawEdgesIterator->hasNext()) break;
-      else drawState++;
-    }
   case DRAWNODE :
   if (!drawNodesIterator->hasNext())
       drawState ++;
@@ -309,6 +329,14 @@ bool GlGraph::drawPart() {
       if (drawNodesIterator->hasNext()) break;
       else drawState++;
      }
+  case DRAWEDGE :
+   if (!_displayEdges || !drawEdgesIterator->hasNext()) 
+      drawState++;
+    else {
+      elementToDraw -= drawEdges(elementToDraw, drawEdgesIterator);
+      if (drawEdgesIterator->hasNext()) break;
+      else drawState++;
+    }
   case DRAWSELECTEDNODELABELS :
      if (!isViewLabel() || !drawSelectedLabelsIterator->hasNext())
       drawState++;
@@ -352,39 +380,25 @@ bool GlGraph::drawPart() {
   else
     nbElementsFrame.set(currentFrame, 1000);
   currentFrame ++;
-  if (finished) strategy->mPaint(this);
-  glFinish();
+  if (finished) mPaint();
   Observable::unholdObservers();
   return finished;
 }
 //====================================================
 void GlGraph::goodScale() {
-  strategy->timerStop();
+  timerStop();
   if (_superGraph==0) return;
   initProxies();
   //  cerr << __PRETTY_FUNCTION__ << endl;
   
-  pair<Coord, Coord> bboxes = tlp::computeBoundingBox(_superGraph, elementLayout, elementSize);
+  pair<Coord, Coord> bboxes = tlp::computeBoundingBox(_superGraph, elementLayout, elementSize, elementRotation);
   Coord maxC = bboxes.first;
   Coord minC = bboxes.second;
-  
-  /*
-  double dx=elementSize->getMax(_superGraph)[0] + elementLayout->getMax(_superGraph)[0]
-    - elementLayout->getMin(_superGraph)[0];
-  double dy=elementSize->getMax(_superGraph)[1] + elementLayout->getMax(_superGraph)[1]
-    - elementLayout->getMin(_superGraph)[1];
-  double dz=elementSize->getMax(_superGraph)[2] + elementLayout->getMax(_superGraph)[2]
-    - elementLayout->getMin(_superGraph)[2];
-  */
+
   double dx = maxC[0] - minC[0];
   double dy = maxC[1] - minC[1];
   double dz = maxC[2] - minC[2];
 
-  /*
-    sceneTranslation[0]=- (elementLayout->getMax(_superGraph)[0]+elementLayout->getMin(_superGraph)[0])/2.0;
-    sceneTranslation[1]=- (elementLayout->getMax(_superGraph)[1]+elementLayout->getMin(_superGraph)[1])/2.0;
-    sceneTranslation[2]=- (elementLayout->getMax(_superGraph)[2]+elementLayout->getMin(_superGraph)[2])/2.0;
-  */
   Coord center = (maxC + minC) / -2.0;
   sceneTranslation = center;
 
@@ -402,8 +416,8 @@ void GlGraph::goodScale() {
 //====================================================
 void GlGraph::outputEPS(int size, int doSort, const char *filename) {
   TRACE_EXEC();
-  strategy->timerStop();
-  strategy->MakeCurrent();
+  timerStop();
+  makeCurrent();
   GLfloat *feedbackBuffer;
   GLint returned;
   FILE *file;
@@ -433,6 +447,7 @@ void GlGraph::outputEPS(int size, int doSort, const char *filename) {
     drawNodeLabels(_superGraph->numberOfNodes(), drawNodesIterator, false);
   delete drawNodesIterator;
   glFlush();
+  glFinish();
   returned = glRenderMode(GL_RENDER);
   if (filename) {
     file = fopen(filename, "w");
@@ -449,35 +464,53 @@ void GlGraph::outputEPS(int size, int doSort, const char *filename) {
 //====================================================
 unsigned char * GlGraph::getImage(int &w, int &h) {
   TRACE_EXEC();
-  strategy->timerStop();
-  strategy->MakeCurrent();
+  timerStop();
+  makeCurrent();
   bool saveState=_incrementalRendering;
   w=winW;
   h=winH;
   unsigned char *image=(unsigned char *)malloc(w*h*3*sizeof(unsigned char));
   _incrementalRendering=false;
   draw();
-  strategy->MakeCurrent(); //necessary because notify inside draw, the openGL context can change.
+  makeCurrent(); //necessary because notify inside draw, the openGL context can change.
+  glFlush();
+  glFinish();
   glPixelStorei(GL_PACK_ALIGNMENT,1);
   glReadPixels(winX,winY,winW,winH,GL_RGB,GL_UNSIGNED_BYTE,image);
   _incrementalRendering=saveState;
   return image;
 }
 //====================================================
-void GlGraph::screenTo3DWorld(double& x,double& y,double& z) {
+void GlGraph::screenTo3DWorld(float& x, float& y, float& z) {
   TRACE_EXEC();
-  strategy->MakeCurrent();
+  makeCurrent();
   double X=x,Y=y;
   double xScr,yScr,zScr;
   GLint realy;
   GLint viewport[4];
   GLdouble modelview[16], projection[16];
-  glGetIntegerv (GL_VIEWPORT, viewport);
+  glGetIntegerv(GL_VIEWPORT, viewport);
   glGetDoublev (GL_MODELVIEW_MATRIX, modelview);
   glGetDoublev (GL_PROJECTION_MATRIX, projection);
   realy = viewport[3] - (GLint) Y - 1;
   gluProject(0,0,0,modelview,projection,viewport,&xScr,&yScr,&zScr);
-  gluUnProject((GLdouble)winW - X, (GLdouble) realy, zScr, modelview, projection, viewport, &x, &y, &z);
+  double _x, _y, _z;
+  gluUnProject((GLdouble)winW - X, (GLdouble) realy, zScr, modelview, projection, viewport, 
+	       &_x, &_y, &_z);
+  x = _x; y = _y; z=_z;
+}
+//====================================================
+void GlGraph::worldTo2DScreen(float& x, float& y, float& z) {
+  TRACE_EXEC();
+  makeCurrent();
+  GLint viewport[4];
+  GLdouble modelview[16], projection[16];
+  glGetIntegerv(GL_VIEWPORT, viewport);
+  glGetDoublev (GL_MODELVIEW_MATRIX, modelview);
+  glGetDoublev (GL_PROJECTION_MATRIX, projection);
+  double _x, _y, _z;
+  gluProject(x, y, z, modelview, projection, viewport, &_x, &_y, &_z);
+  x = _x; y = _y; z=_z;
 }
 //====================================================
 class LessThanNode {
@@ -594,14 +627,16 @@ void GlGraph::deleteIterators() {
 //====================================================
 void GlGraph::initProxies() {
   if (_superGraph != NULL) {
-    elementSelected=_superGraph->getProperty<SelectionProxy>("viewSelection");
-    elementLabel=_superGraph->getProperty<StringProxy>("viewLabel");
-    elementColor=_superGraph->getProperty<ColorsProxy>("viewColor");
-    elementShape=_superGraph->getProperty<IntProxy>("viewShape");
-    elementSize=_superGraph->getProperty<SizesProxy>("viewSize");
-    elementLayout=_superGraph->getProperty<LayoutProxy>(layoutName);
-    elementMetaGraph=_superGraph->getProperty<MetaGraphProxy>("viewMetaGraph");
-    elementTexture=_superGraph->getProperty<StringProxy>("viewTexture");
+    elementRotation   = _superGraph->getProperty<MetricProxy>("viewRotation");
+    elementSelected   = _superGraph->getProperty<SelectionProxy>("viewSelection");
+    elementLabel      = _superGraph->getProperty<StringProxy>("viewLabel");
+    elementLabelColor = _superGraph->getProperty<ColorsProxy>("viewLabelColor");
+    elementColor      = _superGraph->getProperty<ColorsProxy>("viewColor");
+    elementShape      = _superGraph->getProperty<IntProxy>("viewShape");
+    elementSize       = _superGraph->getProperty<SizesProxy>("viewSize");
+    elementLayout     = _superGraph->getProperty<LayoutProxy>(layoutName);
+    elementMetaGraph  = _superGraph->getProperty<MetaGraphProxy>("viewMetaGraph");
+    elementTexture    = _superGraph->getProperty<StringProxy>("viewTexture");
   }
 }
 //====================================================
