@@ -11,25 +11,29 @@
 #include <GL/glu.h>
 
 using namespace std;
-
+//==========================================================
 Coord GlGraph::getSceneTranslation() const {
   return sceneTranslation;
 }
+//==========================================================
 void GlGraph::setSceneTranslation(const Coord &c){
   TRACE_EXEC(); 
   sceneTranslation=c;
 }
+//==========================================================
 Coord GlGraph::getSceneRotation() const {
   return sceneRotation;
 }
+//==========================================================
 void GlGraph::setSceneRotation(const Coord &c) {
   TRACE_EXEC(); 
   sceneRotation=c;
 }
+//==========================================================
 void GlGraph::translateCamera(const int x, const int y, const int z) {
-  double x0=0,y0=0,z0=0;
-  double x1=x,y1=y,z1=z;
-  strategy->MakeCurrent();
+  float x0=0,y0=0,z0=0;
+  float x1=x,y1=y,z1=z;
+  makeCurrent();
   glMatrixMode(GL_MODELVIEW);
   glPushMatrix();
   glLoadIdentity();
@@ -37,30 +41,29 @@ void GlGraph::translateCamera(const int x, const int y, const int z) {
   screenTo3DWorld(x0,y0,z0);
   screenTo3DWorld(x1,y1,z1);
   glPopMatrix();
-
-  Coord tmp=Coord(x1-x0,(y1-y0),(z1-z0));
-  cameraEyes+=tmp;
-  cameraCenter+=tmp;
-  strategy->toUpdate=true;
-  strategy->UpdateGL();
+  Coord move((x1-x0), (y1-y0), (z1-z0));
+  cameraEyes += move;
+  cameraCenter += move;
+  toUpdate = true;
+  updateGL();
 }
 //==========================================================
 void GlGraph::zoom(int step) {
-  strategy->toUpdate=true;
+  toUpdate=true;
   int signeZ = (step < 0) ? -1 : 1;
   if (step<0) step=-step;
   if (signeZ>0)
     cameraZoomFactor*=pow(1.1,step);
   else
     cameraZoomFactor/=pow(1.1,step);
-  strategy->toUpdate=true;
-  strategy->UpdateGL();
+  toUpdate=true;
+  updateGL();
 }
 //================================================
 void GlGraph::rotateScene(const int x, const int y, const int z) {
   sceneRotation+=Coord(2*x,2*y,2*z);
-  strategy->toUpdate=true;
-  strategy->UpdateGL();  
+  toUpdate=true;
+  updateGL();  
 }
 //==================================================
 void GlGraph::zoomXY(int step, const int x, const int y) {
@@ -76,6 +79,6 @@ void GlGraph::zoomXY(int step, const int x, const int y) {
   else
     cameraZoomFactor/=pow(1.1,step);
   translateCamera(factX,-factY,0);
-  // strategy->toUpdate=true;
-  // strategy->UpdateGL();  
+  // toUpdate=true;
+  // UpdateGL();  
 }
