@@ -1,25 +1,20 @@
 #include "tulip/Hline.h"
-#include "tulip/DynamicFunctions.h"
+#include "tulip/Renderer.h"
 
 const int HAUTEUR=5; // défini l'espace avant et après la ligne horizontale
 
 void Hline::draw(float w_max, float& w)const{
- 
-  DynamicFunctions* myRendu = DynamicFunctions::create();
-
-  myRendu->setColor(couleur[0], couleur[1], couleur[2]);
-  myRendu->translate(0,-HAUTEUR,0); 
-
-  myRendu->drawLine(0, 0, 0, w_max, 0, 0);
-
-  // repositionnement en dessous du trait
-  myRendu->translate(0,-HAUTEUR,0);
+  renderer.setColor(couleur[0], couleur[1], couleur[2]);
+  renderer.translate(0,-HAUTEUR,0); 
+  renderer.drawLine(0, 0, 0, w_max, 0, 0);
+  renderer.translate(0,-HAUTEUR,0);
   w = w_max;
 }
 
 void Hline::getBoundingBox(float w_max, float& h, float& w)const{
   h = 2*HAUTEUR;
-  w = w_max;
+  //  w = w_max;
+  w = 1.0; 
 }
 
 void Hline::getColor(unsigned char& r, unsigned char& v, unsigned char& b) const{
