@@ -10,7 +10,7 @@
 
 #include <tulip/tulipconf.h>
 #include <tulip/MutableContainer.h>
-#include "ClusterTreeData.h"
+#include "tulip/ClusterTreeData.h"
 
 class SuperGraph;
 class QListViewItem;
