@@ -13,7 +13,7 @@ class SelectionProxy;
 #include "tulip/Qt3ForTulip.h"
 #endif
 
-#include "FindSelectionData.h"
+#include "tulip/FindSelectionData.h"
 
 struct TLP_QT_SCOPE GItem {
   GItem( const node & inN ): n(inN), isnode(true) {}
