@@ -25,7 +25,7 @@
 #else
 #include <QtOpenGL/qgl.h>
 #include <QtCore/qpoint.h>
-#include "Qt3ForTulip.h"
+#include "tulip/Qt3ForTulip.h"
 #endif
 
 #include "tulip/MouseInterface.h"
@@ -72,6 +72,37 @@ public:
   void  removeGlAugmentedDisplay(tlp::GlAugmentedDisplay *augmentedDisplay);
   void  removeGlAugmentedDisplay(const char* key);
   tlp::GlAugmentedDisplay* findGlAugmentedDisplay(const char* key);
+
+  /**
+   * Function to do picking on augmented displays.  It just calls
+   * doSelect on the GlADComposite instance.
+   */
+  inline bool doSelectAugmentedDisplay (const int x, const int y, 
+					const int width, const int height,
+					std::vector <std::pair <string, 
+					tlp::GlAugmentedDisplay *> >
+					&pickedAugmentedDisplays) {
+    if (composite != 0)
+      return composite->doSelect (x, y, width, height, pickedAugmentedDisplays,
+				  this);
+    else return false;
+  }
+
+  /**
+   * Function to do picking on augmented displays.  It just calls
+   * doSelect on the GlADComposite instance with a small window of 
+   * twelve pixels.
+   */
+  inline bool doSelectAugmentedDisplay (const int x, const int y,
+					std::vector <std::pair <string, 
+					tlp::GlAugmentedDisplay *> >
+					&pickedAugmentedDisplays) {
+    if (composite != 0)
+      return composite->doSelect (x-3, y-3, 6, 6, pickedAugmentedDisplays,
+				  this);
+    else return false;
+  }
+
   /////////////////////////////////////
 
   //MouseInterface implementation can use the following methods. Not very pretty...
