@@ -6,8 +6,7 @@ class QKeyEvent;
 class QWheelEvent;
 class GlGraphWidget;
 ///
-class MouseInterface
-{
+class MouseInterface {
  public:
   MouseInterface() {}
   virtual ~MouseInterface() {}
@@ -18,6 +17,7 @@ class MouseInterface
   virtual void keyPressEvent (GlGraphWidget *, QKeyEvent *)=0;
   virtual void keyReleaseEvent(GlGraphWidget *, QKeyEvent *)=0;
   virtual void wheelEvent(GlGraphWidget *, QWheelEvent *)=0;
+  virtual MouseInterface* clone() = 0;
 };
 
 #endif
