@@ -12,14 +12,10 @@
 class SuperGraph;
 class QMouseEvent;
 class QKeyEvent;
+/** \addtogroup Mouse_interactor */ 
+/*@{*/
 
-class TLP_QT_SCOPE MouseZoomBox : public MouseInterface
-{
-private:
-  unsigned int x, y;
-  int w, h;
-  bool started;
-  SuperGraph *superGraph;
+class TLP_QT_SCOPE MouseZoomBox : public MouseInterface {
 
 public:
   MouseZoomBox();
@@ -31,7 +27,13 @@ public:
   void keyPressEvent (GlGraphWidget *, QKeyEvent *){}
   void keyReleaseEvent(GlGraphWidget *, QKeyEvent *){}
   void wheelEvent(GlGraphWidget *, QWheelEvent *){}
+  MouseInterface * clone() { return new MouseZoomBox();}
 
+private:
+  unsigned int x, y;
+  int w, h;
+  bool started;
+  SuperGraph *superGraph;
 };
-
+/*@}*/
 #endif //MOUSEZOOMBOX_H
