@@ -18,7 +18,7 @@
 #else
 #include <QtGui/qwidget.h>
 #include <QtGui/qscrollbar.h>
-#include "Qt3ForTulip.h"
+#include "tulip/Qt3ForTulip.h"
 #endif
 
 #include <tulip/SuperGraph.h>
