@@ -2,6 +2,10 @@
 #ifndef _TLPQTTOOLS_H
 #define _TLPQTTOOLS_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 
 #include "tulip/Reflect.h"
 #include "tulip/SuperGraph.h"
@@ -18,7 +22,7 @@ namespace tlp {
    * [inSet		: Input (optional) set, containing some default values]
    */
 
-  bool openDataSetDialog	(	DataSet &			outSet,
+  TLP_QT_SCOPE bool openDataSetDialog	(	DataSet &			outSet,
 								const StructDef &	inDef,
 								const DataSet *		inSet	= NULL,
 								const char *		inName	= NULL,
