@@ -16,7 +16,7 @@
 
 #include <tulip/SuperGraph.h>
 #include <tulip/ObservableGraph.h>
-#include "TulipElementPropertiesData.h"
+#include "tulip/TulipElementPropertiesData.h"
 
 class TLP_QT_SIMPLE_SCOPE TulipElementProperties : public TulipElementPropertiesData, public GraphObserver
 {
