@@ -14,31 +14,36 @@
 #include "tulip/ColorsProxy.h"
 #include "tulip/SizesProxy.h"
 
-#include <qapplication.h>
+#if (QT_REL == 3)
 #include <qvalidator.h>
-#include <qeventloop.h>
 #include <qdialog.h>
-#include <qpushbutton.h>
-#include <qlayout.h>
 #include <qframe.h>
-#include <qpopupmenu.h>
-#include <qbuttongroup.h>
-#include <qhbox.h>
-#include <qradiobutton.h>
 #include <qcheckbox.h>
-#include <qgroupbox.h>
 #include <qpushbutton.h>
 #include <qlabel.h>
 #include <qlineedit.h>
-#include <qlabel.h>
-#include <qcheckbox.h>
 #include <qcombobox.h>
 #include <qcolordialog.h>
 #include <qfiledialog.h>
 #include <qtoolbutton.h>
 #include <qwidget.h>
 #include <qtextbrowser.h>
-
+#else
+#include <QtGui/qvalidator.h>
+#include <QtGui/qdialog.h>
+#include <QtGui/qframe.h>
+#include <QtGui/qcheckbox.h>
+#include <QtGui/qpushbutton.h>
+#include <QtGui/qlabel.h>
+#include <QtGui/qlineedit.h>
+#include <QtGui/qcombobox.h>
+#include <QtGui/qcolordialog.h>
+#include <QtGui/qfiledialog.h>
+#include <QtGui/qtoolbutton.h>
+#include <QtGui/qwidget.h>
+#include <QtGui/qtextbrowser.h>
+#include "tulip/Qt3ForTulip.h"
+#endif
 
 
 using namespace std;
@@ -102,7 +107,7 @@ namespace {
     while( it->hasNext() ) {
       pair<string,DataType> p;
       p = it->next();
-      cout << p.first << " : " << int( p.second.value ) << endl;
+      cout << p.first << " : " << (unsigned long)p.second.value << endl;
     } delete it;
   }
 
@@ -124,7 +129,7 @@ namespace {
 
   struct QParamDialog : public QDialog {
 
-    QParamDialog( QWidget * parent = 0, const char * name = 0, bool modal = FALSE, WFlags f = 0 )
+    QParamDialog( QWidget * parent = 0, const char * name = 0, bool modal = FALSE, Qt::WFlags f = 0 )
       : QDialog( parent, name, modal, f ) {
       helpBrowser = 0;
       curHelpParam = -1;
@@ -152,7 +157,11 @@ namespace {
 	curHelpParam = ipIdx;
 
 	if( ip->helpText.size() )
+#if (QT_REL == 3)  
 	  helpBrowser->setText( ip->helpText.c_str() );
+#else
+	  helpBrowser->setHtml( ip->helpText.c_str() );
+#endif
 	else
 	  helpBrowser->setText( NO_HELP_AVAILABLE_MSG );
       }
@@ -172,17 +181,21 @@ namespace {
 	  QLineEdit * leR = (QLineEdit*) ip->wA[0];
 	  QLineEdit * leG = (QLineEdit*) ip->wA[2];
 	  QLineEdit * leB = (QLineEdit*) ip->wA[4];
-	  QColor rgb( leR->text().toInt(),
-		      leG->text().toInt(),
-		      leB->text().toInt()	);
+	  QLineEdit * leA = (QLineEdit*) ip->wA[6];
+	  QRgb rgb = qRgba( leR->text().toInt(),
+			    leG->text().toInt(),
+			    leB->text().toInt(),
+			    leA->text().toInt()
+			    );
 	  bool ok = false;
-	  rgb.setRgb( QColorDialog::getRgba(rgb.rgb(),&ok) );
+	  rgb = QColorDialog::getRgba(rgb,&ok);
 	  if( ok ) {
-	    leR->setText( QString("%1").arg(rgb.red()) );
-	    leG->setText( QString("%1").arg(rgb.green()) );
-	    leB->setText( QString("%1").arg(rgb.blue()) );
+	    leR->setText( QString("%1").arg(qRed(rgb)));
+	    leG->setText( QString("%1").arg(qGreen(rgb)));
+	    leB->setText( QString("%1").arg(qBlue(rgb)));
+	    leA->setText( QString("%1").arg(qAlpha(rgb)));
 	  }
-	  ((QWidget *)obj)->setPaletteBackgroundColor(rgb);
+	  ((QWidget *)obj)->setPaletteBackgroundColor(QColor(rgb));
 	  return false;
 	} else if( ip->typeName == TN(string) ) {
 	  QString s = QFileDialog::getOpenFileName();
@@ -212,7 +225,13 @@ namespace {
 	ip.name     = def.first;
 	ip.typeName = def.second;
 	ip.helpText = inDef.getHelp(ip.name);
-	ip.label    = new QLabel( ip.name.c_str(), this );
+	// first part of the parameter name may be used
+	// to indicate a subtype
+	string::size_type pos = def.first.find("::");
+	if (pos != string::npos)
+	  ip.label = new QLabel(def.first.substr(pos + 2, def.first.length() - pos - 2).c_str(), this);
+	else
+	  ip.label    = new QLabel( ip.name.c_str(), this );
 	ip.label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
 	ip.label->installEventFilter( this );
 	ip.label->setMouseTracking( true );
@@ -256,34 +275,63 @@ namespace {
 	if (ip.typeName == TN(float)
 	    || ip.typeName == TN(double)) {
 	  QValidator* fpValidator = new QDoubleValidator( this );
+	  
 	  QLineEdit * le = new QLineEdit( "0", this );
 	  le->setValidator( fpValidator );
 	  ip.wA.push_back( le );
 	  if( inSet ) {
-	    float v;
-	    if( inSet->get
-		(ip.name,v) )
-	      le->setText( QString("%1").arg(v) );
+	    stringstream tmp;
+	    if (ip.typeName == TN(float)) {
+	      float v;
+	      if( inSet->get(ip.name,v) ) {
+		tmp << v;
+		le->setText( tmp.str().c_str() );
+	      }
+	    } else {
+	      double d;
+	      if (inSet->get(ip.name, d)){
+		tmp << d;
+		le->setText( tmp.str().c_str()  );
+	      }
+	    }
 	  }
 	}
-
 	// string
 	else if( ip.typeName == TN(string) ) {
-	  QLineEdit * le = new QLineEdit( "", this );
-	  le->resize( le->width()*3, le->height() );
-	  QToolButton * opt = new QToolButton( this );
-	  opt->setText( "..." );
-	  opt->adjustSize();
-	  opt->resize( opt->width(), le->height() );
-	  ip.opt = opt;
-	  opt->installEventFilter( this );
-	  ip.wA.push_back( le );
-	  ip.wA.push_back( opt );
-	  if( inSet ) {
-	    string v;
-	    if( inSet->get
-		(ip.name,v) )
-	      le->setText( v.c_str() );
+	  // if text prefixed than create a QTextEdit
+	  if (ip.name.find("text::") != string::npos) {
+	    QTextEdit *te = new QTextEdit(QString(""),
+#if (QT_REL == 3)
+					  QString::null,
+#endif
+					  this);
+	    te->resize(te->width() * 3, te->height()*3);
+	    ip.wA.push_back(te);
+	    if( inSet ) {
+	      string v;
+	      if( inSet->get
+		  (ip.name, v) )
+		te->setText( v.c_str() );
+	    }
+	  } else {
+	    QLineEdit * le = new QLineEdit( "", this );
+	    le->resize( le->width()*3, le->height() );
+	    ip.wA.push_back( le );
+	    if( inSet ) {
+	      string v;
+	      if( inSet->get
+		  (ip.name, v) )
+		le->setText( v.c_str() );
+	    }
+	    if (ip.name.find("file::") == 0) {
+	      QToolButton * opt = new QToolButton( this );
+	      opt->setText( "..." );
+	      opt->adjustSize();
+	      opt->resize( opt->width(), le->height() );
+	      ip.opt = opt;
+	      opt->installEventFilter( this );
+	      ip.wA.push_back( opt );
+	    }
 	  }
 	}
 
@@ -430,7 +478,8 @@ namespace {
 
       int labelWidthMax = 0;
       for( uint i = 0 ; i < iparamA.size() ; i++ )
-	labelWidthMax = labelWidthMax >? iparamA[i].label->width();
+	if (labelWidthMax < iparamA[i].label->width())
+	  labelWidthMax = iparamA[i].label->width();
 
       int ix = 5, iy = 5;
       int y  = iy;
@@ -447,13 +496,16 @@ namespace {
 	ip.label->move( ix, y );
 
 	int x = labelWidthMax+ix*2;
+	int maxHeight = 0;
 	for( uint j = 0 ; j < ip.wA.size() ; j++ ) {
 	  ip.wA[j]->move( x, y );
 	  x += ip.wA[j]->width() + ix;
+	  if (ip.wA[j]->height() > maxHeight)
+	    maxHeight = ip.wA[j]->height();
 	}
-	maxx = maxx >? x;
+	if (maxx < x) maxx = x; //maxx = maxx >? x;
 
-	y += ip.label->height() + iy;
+	y += /* ip.label->height()*/ maxHeight + iy;
       }
 
       y += iy;
@@ -532,8 +584,13 @@ namespace {
 
 	// string
 	else if(	ip.typeName == TN(string)	) {
-	  QLineEdit * le = (QLineEdit *) ip.wA[0];
-	  outSet.set<string>( ip.name, le->text().ascii() );
+	  if (ip.name.find("text::") != string::npos) {
+	    QTextEdit *te = (QTextEdit *) ip.wA[0];
+	    outSet.set<string>(ip.name, te->text().ascii());
+	  } else {
+	    QLineEdit * le = (QLineEdit *) ip.wA[0];
+	    outSet.set<string>( ip.name, le->text().ascii() );
+	  }
 	}
 
 	// Color
