@@ -2,6 +2,7 @@
 #include <sstream>
 #include <string>
 
+#if (QT_REL == 3)
 #include <qstring.h>
 #include <qpushbutton.h>
 #include <qfiledialog.h>
@@ -17,6 +18,24 @@
 #include <qsizepolicy.h>
 #include <qmessagebox.h>
 #include <qinputdialog.h>
+#else
+#include <QtCore/qstring.h>
+#include <QtGui/qpushbutton.h>
+#include <QtGui/qfiledialog.h>
+#include <QtGui/qcolordialog.h>
+#include <QtGui/qpainter.h>
+#include <QtGui/qfontmetrics.h>
+#include <QtGui/qapplication.h>
+#include <QtGui/qlayout.h>
+#include <QtGui/qlineedit.h>
+#include <QtCore/qdir.h>
+#include <QtCore/qfileinfo.h>
+#include <QtGui/qvalidator.h>
+#include <QtGui/qsizepolicy.h>
+#include <QtGui/qmessagebox.h>
+#include <QtGui/qinputdialog.h>
+#include "tulip/Qt3ForTulip.h"
+#endif
 
 #include <tulip/SuperGraph.h>
 #include <tulip/PropertyManager.h>
@@ -281,7 +300,8 @@ void TulipPropertyTable::setAllNodeValue() {
 
   if (editedPropertyName == "viewShape") {
     QStringList tmp;
-    Iterator<string> *itS=GlGraph::glyphFactory.availablePlugins();
+    GlGraph::initFactory();
+    Iterator<string> *itS=GlGraph::glyphFactory->availablePlugins();
     while (itS->hasNext()){
       tmp.append(QString(itS->next().c_str()));
     }delete itS;
@@ -307,12 +327,11 @@ void TulipPropertyTable::setAllNodeValue() {
     }
   }
   else if (typeid(*editedProperty) == typeid(ColorsProxy)) {
-    QColor color = QColorDialog::getColor();
-    if (color.isValid()) {
+    QRgb col = QColorDialog::getRgba(qRgba(0,0,0,200), &ok);
+    if (ok) {
       stringstream ss;
-      ss << "(" << color.red() << "," << color.green() << "," << color.blue() << ",255)";
+      ss << "(" << qRed(col) << "," << qGreen(col) << "," << qBlue(col) << "," << qAlpha(col) << ")";
       tmpStr = ss.str();
-      ok = true;
     }
   }
   else {
@@ -367,12 +386,25 @@ void  TulipPropertyTable::setAllEdgeValue() {
   string tmpStr;
 
   if (typeid(*editedProperty) == typeid(ColorsProxy)) {
-    QColor color = QColorDialog::getColor();
-    if (color.isValid()) {
+    QRgb col = QColorDialog::getRgba(qRgba(255,0,0,200), &ok);
+    if (ok) {
       stringstream ss;
-      ss << "(" << color.red() << "," << color.green() << "," << color.blue() << ",255)";
+      ss << "(" << qRed(col) << "," << qGreen(col) << "," << qBlue(col) << "," << qAlpha(col) << ")";
+      tmpStr = ss.str();
+    }
+  }
+  else if (editedPropertyName == "viewShape") {
+    QStringList tmp;
+    for (int i = 0; i < GlGraph::edgeShapesCount; i++)
+      tmp.append(QString(GlGraph::edgeShapeName(GlGraph::edgeShapeIds[i]).c_str()));
+    
+    QString shapeName = QInputDialog::getItem(string("Property \"" + editedPropertyName + "\": set all node value").c_str(),
+                                              "Please choose a shape",
+                                              tmp, 0, false, &ok, this);
+    if (ok) {
+      stringstream ss;
+      ss << GlGraph::edgeShapeId(shapeName.ascii());
       tmpStr = ss.str();
-      ok = true;
     }
   }
   else {
