@@ -2,6 +2,7 @@
 #include <sstream>
 #include <string>
 
+#if (QT_REL == 3)
 #include <qstring.h>
 #include <qpushbutton.h>
 #include <qfiledialog.h>
@@ -17,6 +18,25 @@
 #include <qsizepolicy.h>
 #include <qmessagebox.h>
 #include <qinputdialog.h>
+#else
+#include <QtCore/qstring.h>
+#include <QtGui/qpushbutton.h>
+#include <QtGui/qfiledialog.h>
+#include <QtGui/qcolordialog.h>
+#include <QtGui/qpainter.h>
+#include <QtGui/qfontmetrics.h>
+#include <QtGui/qapplication.h>
+#include <QtGui/qlayout.h>
+#include <QtGui/qlineedit.h>
+#include <QtCore/qdir.h>
+#include <QtCore/qfileinfo.h>
+#include <QtGui/qvalidator.h>
+#include <QtGui/qsizepolicy.h>
+#include <QtGui/qmessagebox.h>
+#include <QtGui/qinputdialog.h>
+#include <QtGui/qevent.h>
+#include "tulip/Qt3ForTulip.h"
+#endif
 
 #include <tulip/SuperGraph.h>
 #include <tulip/PropertyManager.h>
@@ -37,34 +57,38 @@
 #define COORDTABLEITEM_RTTI 1004
 #define GLYPHTABLEITEM_RTTI 1005
 #define SELECTIONTABLEITEM_RTTI 1006
+#define EDGESHAPETABLEITEM_RTTI 1007
 
 using namespace std;
 //================================================================================
-ColorButton::ColorButton(const QColor &c, QWidget *parent, const char *name, WFlags f) :
+ColorButton::ColorButton(const QRgb &c, QWidget *parent, const char *name, Qt::WFlags f) :
     QButton(parent, name, f), color(c) {
   connect(this, SIGNAL(pressed()), SLOT(colorDialog()));
   emit pressed();
   setFocusPolicy(StrongFocus);
 }
 ColorButton::~ColorButton() {}
-QColor ColorButton::getColor() const {
+QRgb ColorButton::getColor() const {
   return color;
 }
 void ColorButton::colorDialog() {
-  QColor tmpcolor = QColorDialog::getColor();
-  if (tmpcolor.isValid()) color = tmpcolor;
+  bool ok;
+  QRgb tmpcolor = QColorDialog::getRgba(color, &ok);
+  if (ok) color = tmpcolor;
 }
 void ColorButton::paintEvent(QPaintEvent *qpe) {
   QPainter p(this);
-  p.fillRect(qpe->rect(), color);
+  p.fillRect(qpe->rect(), QColor(color));
+#if (QT_REL == 3)
   p.flush();
+#endif
 }
 //================================================ 
-ColorTableItem::ColorTableItem(QTable *table, const QColor &color) :
+ColorTableItem::ColorTableItem(QTable *table, const QRgb &color) :
   QTableItem(table, OnTyping, ""), color(color) {}
 ColorTableItem::~ColorTableItem() {}
 int ColorTableItem::rtti() const {return COLORTABLEITEM_RTTI;}
-QColor ColorTableItem::getColor() const {return color;}
+QRgb ColorTableItem::getColor() const {return color;}
 QWidget *ColorTableItem::createEditor() const {
   ColorButton *cb = new ColorButton(color, table()->viewport());
   return cb;
@@ -73,16 +97,14 @@ void ColorTableItem::setContentFromEditor(QWidget *w) {
   //  cerr << __PRETTY_FUNCTION__ << endl;
   color = ((ColorButton *)w)->getColor();
   stringstream ss;
-  ss << "(" << color.red() << "," << color.green() << "," << color.blue() << ",255)";
-  #if defined _WIN32 || (__CYGWIN__)
-    setText(ss.str().c_str());
-  #else
-  setText(ss.str());
-  #endif
+  ss << "(" << qRed(color) << "," << qGreen(color) << "," << qBlue(color) << "," << qAlpha(color) << ")";
+  setText(ss.str().c_str());
 }
 void ColorTableItem::paint(QPainter *p, const QColorGroup &cg, const QRect &cr, bool selected) {
-  p->fillRect(table()->cellRect(row(), col()), color);
+  p->fillRect(table()->cellRect(row(), col()), QColor(color));
+#if (QT_REL == 3)
   p->flush();
+#endif
 }
 //================================================================================
 FilenameEditor::FilenameEditor(const QString &filter, QWidget *parent, const char *name) :
@@ -107,7 +129,7 @@ QString FilenameEditor::fileName() const {
   return lineedit->text();
 }
 void FilenameEditor::setFileName(const QString &s) {
-  cerr << __PRETTY_FUNCTION__ << s << endl;
+  cerr << __PRETTY_FUNCTION__ << (const char *) s << endl;
   lineedit->setText(s);
 }
 QString FilenameEditor::filter() const {
@@ -117,13 +139,21 @@ void FilenameEditor::setFilter(const QString &f) {
   fileFilter = f;
 }
 void FilenameEditor::buttonPressed() {
+#if (QT_REL == 3)
   QFileDialog *dlg = new QFileDialog("./",
                                      fileFilter,
                                      this,
                                      "FilenameEditor->FileDialog",
                                      true);
-  dlg->setMode(QFileDialog::ExistingFile);
   dlg->setCaption(tr("Choose a file"));
+#else
+  QFileDialog *dlg = new QFileDialog(this,
+				     "Choose a file",
+				     "./",
+                                     fileFilter);
+  dlg->setModal(true);
+#endif
+  dlg->setMode(QFileDialog::ExistingFile);
   if (dlg->exec() == QDialog::Accepted ) {
     QString file = dlg->selectedFile();
     if (!file.isNull()) {
@@ -141,7 +171,7 @@ void FilenameEditor::buttonPressed() {
         currentDir.pop_front();
       }
       if (!filePath.empty())
-        relativePath += filePath.join(QChar(QDir::separator())) + QDir::separator();
+        relativePath += filePath.join((const QString) (QChar) QDir::separator()) + QDir::separator();
       setFileName(relativePath + QFileInfo(file).fileName());
     }
   }
@@ -161,7 +191,7 @@ QWidget *FileTableItem::createEditor() const {
 void FileTableItem::setContentFromEditor(QWidget *w) {
   cerr << __PRETTY_FUNCTION__ << endl;
   QString s = ((FilenameEditor *)w)->fileName();
-  cerr << "String : " << s << endl;
+  cerr << "String : " << (const char *) s << endl;
   if (!s.isNull()) {
     string str(s.latin1());
     cerr << "setText" << endl;
@@ -188,7 +218,7 @@ SizeEditor::SizeEditor(const Size &s, QWidget *parent, const char *name) : QWidg
   connect(edit[0], SIGNAL(textChanged(const QString &)), this, SLOT(changeW(const QString &)));
   connect(edit[1], SIGNAL(textChanged(const QString &)), this, SLOT(changeH(const QString &)));
   connect(edit[2], SIGNAL(textChanged(const QString &)), this, SLOT(changeD(const QString &)));
-  setFocusPolicy(QWidget::StrongFocus);
+  setFocusPolicy(StrongFocus);
 }
 
 SizeEditor::~SizeEditor() {}
@@ -247,7 +277,7 @@ CoordEditor::CoordEditor(const Coord &c, QWidget *parent, const char *name) : QW
   connect(edit[0], SIGNAL(textChanged(const QString &)), this, SLOT(changeX(const QString &)));
   connect(edit[1], SIGNAL(textChanged(const QString &)), this, SLOT(changeY(const QString &)));
   connect(edit[2], SIGNAL(textChanged(const QString &)), this, SLOT(changeZ(const QString &)));
-  setFocusPolicy(QWidget::StrongFocus);
+  setFocusPolicy(StrongFocus);
 }
 
 CoordEditor::~CoordEditor() {}
@@ -293,7 +323,8 @@ void CoordTableItem::setContentFromEditor(QWidget *w) {
 GlyphTableItem::GlyphTableItem(QTable *table, bool editable) :
   QComboTableItem(table,QStringList(), editable) {
   QStringList tmp;
-  Iterator<string> *itS=GlGraph::glyphFactory.availablePlugins();
+  GlGraph::initFactory();
+  Iterator<string> *itS=GlGraph::glyphFactory->availablePlugins();
   while (itS->hasNext()) {
     tmp.append(QString(itS->next().c_str()));
   } delete itS;
@@ -308,6 +339,22 @@ QString GlyphTableItem::text() const {
   return QString(ss.str().c_str());
 }
 //================================================================================
+EdgeShapeTableItem::EdgeShapeTableItem(QTable *table, bool editable) :
+  QComboTableItem(table,QStringList(), editable) {
+  QStringList tmp;
+  for (int i = 0; i < GlGraph::edgeShapesCount; i++)
+    tmp.append(QString(GlGraph::edgeShapeName(GlGraph::edgeShapeIds[i]).c_str()));
+  setStringList(tmp);
+}
+EdgeShapeTableItem::~EdgeShapeTableItem() {}
+int EdgeShapeTableItem::rtti() const {return EDGESHAPETABLEITEM_RTTI;}
+
+QString EdgeShapeTableItem::text() const {
+  stringstream ss;
+  ss << GlGraph::edgeShapeId(this->currentText().ascii());
+  return QString(ss.str().c_str());
+}
+//================================================================================
 SelectionTableItem::SelectionTableItem(QTable *table, const QString &txt) :
   QCheckTableItem(table, txt) {}
 SelectionTableItem::~SelectionTableItem() {}
@@ -374,7 +421,7 @@ void TulipTableWidget::setTulipNodeItem(const PProxy *editedProperty, const std:
   else if (typeid(*editedProperty) == typeid(ColorsProxy)) {
     ColorsProxy *tmpCol = (ColorsProxy *)editedProperty;
     Color c = tmpCol->getNodeValue(n);
-    ColorTableItem *item = new ColorTableItem(this, QColor(c.getR(), c.getG(), c.getB()));
+    ColorTableItem *item = new ColorTableItem(this, qRgba(c[0], c[1], c[2], c[3]));
     label = tr("Color");
     this->setItem(row, col, item);
   }
@@ -419,7 +466,7 @@ void TulipTableWidget::setTulipEdgeItem(const PProxy *editedProperty, const std:
   else if (typeid(*editedProperty) == typeid(ColorsProxy)) {
     ColorsProxy *tmpCol = (ColorsProxy *)editedProperty;
     Color c = tmpCol->getEdgeValue(e);
-    ColorTableItem *item = new ColorTableItem(this, QColor(c.getR(), c.getG(), c.getB()));
+    ColorTableItem *item = new ColorTableItem(this, qRgba(c[0], c[1], c[2], c[3]));
     label = tr("Color");
     this->setItem(row, col, item);
   }
@@ -430,6 +477,13 @@ void TulipTableWidget::setTulipEdgeItem(const PProxy *editedProperty, const std:
     item->setSize(s);
     label = tr("Size");
     this->setItem(row, col, item);
+  } else if (propertyName == "viewShape") {
+    EdgeShapeTableItem *item = new EdgeShapeTableItem(this, false);
+    int shapenum = ((IntProxy *)editedProperty)->getEdgeValue(e);
+
+    label = tr("Shape");
+    this->setItem(row, col, item);
+    item->setCurrentItem(GlGraph::edgeShapeName(shapenum).c_str());
   }
 //   else if (typeid(*editedProperty) == typeid(LayoutProxy)) {
 //     LayoutProxy *tmpLay = getProperty<LayoutProxy>(supergraph, propertyName);
