@@ -50,6 +50,10 @@ class Color : public tlp::Vector<unsigned char,4>{
   ///
   void setV(int );
 };
+
+std::ostream& operator<<(std::ostream &os,const Color &);
+std::istream& operator>>(std::istream &is, Color &);
+
 Color::Color(const unsigned char red ,const unsigned char green ,const unsigned char blue,const unsigned char alpha) {
   array[0]=red;
   array[1]=green;
@@ -68,10 +72,10 @@ unsigned char Color::getG()const{return array[1];}
 unsigned char Color::getB()const{return array[2];}
 unsigned char Color::getA()const{return array[3];}
 
-float Color::getRGL()const{return (float)array[0]/255;}
-float Color::getGGL()const{return (float)array[1]/255;}
-float Color::getBGL()const{return (float)array[2]/255;}
-float Color::getAGL()const{return (float)array[3]/255;}
+float Color::getRGL()const{return (float)array[0]/255.0;}
+float Color::getGGL()const{return (float)array[1]/255.0;}
+float Color::getBGL()const{return (float)array[2]/255.0;}
+float Color::getAGL()const{return (float)array[3]/255.0;}
 float* Color::getGL()const{
   float *result=new float[4];
   result[0]=getRGL();
