@@ -1,5 +1,5 @@
 //-*-c++-*-
-/**
+/*
  Author: David Auber
  Email : auber@labri.fr
  Last modification : 20/08/2001
@@ -34,7 +34,7 @@ protected:
   ///
   Colors (const PropertyContext & context);
   ///
-  virtual ~Colors(){}
+  virtual ~Colors();
 };
 /*@}*/
 #endif
