@@ -10,6 +10,7 @@
  * \defgroup graphs
  */ 
 /*@{*/
+/// class edge
 struct edge { 
   unsigned int id;
   edge():id(UINT_MAX){}
@@ -21,6 +22,8 @@ struct edge {
 
 /*@}*/
 
+#ifndef DOXYGEN_NOTFOR_DEVEL
+
 namespace stdext {
   template<>
   struct hash<edge>{
@@ -38,5 +41,5 @@ namespace std {
     return e.id<e2.id;}
   };
 }
-
+#endif
 #endif
