@@ -16,7 +16,7 @@ namespace tlp {
   TLP_SCOPE double averageCluster(SuperGraph *);
   TLP_SCOPE unsigned int maxDegree(SuperGraph *);
   TLP_SCOPE unsigned int minDegree(SuperGraph *);
-  TLP_SCOPE unsigned int maxDistance(SuperGraph *graph, node n, MutableContainer<unsigned int> &distance, int direction);
+  TLP_SCOPE unsigned int maxDistance(SuperGraph *graph, node n, MutableContainer<unsigned int> &distance, int direction = 2);
 };
 
 #endif
