@@ -1,5 +1,5 @@
 //-*-c++-*-
-/**
+/*
  Author: David Auber
  Email : auber@labri.fr
  Last modification : 01/09/2003
@@ -12,6 +12,7 @@
 #include <tulip/SuperGraph.h>
 #include <tulip/tulipconf.h>
 #include <list>
+#include <vector>
 
 #ifndef TULIP_NODEMAPITERATOR_H
 #define TULIP_NODEMAPITERATOR_H
