@@ -1,5 +1,5 @@
 //-*-c++-*-
-/**
+/*
  Author: David Auber
  Email : auber@labri.fr
  Last modification : 20/08/2001
@@ -27,7 +27,8 @@ class MetaGraph:public Property<MetaGraphType , MetaGraphType>
   friend class MetaGraphProxy;
 public:
   /** This metagraph proxy is the one associated to the plug-ins,
-      The data should be store in it*/
+    *  The data should be store in it
+    */
   MetaGraphProxy *metaGraphProxy;
 protected:
   ///
