@@ -3,7 +3,6 @@
 #define TULIP_METRICPROXY_H
 
 #include "PropertyProxy.h"
-#include "MethodFactory.h"
 #include "TemplateFactory.h"
 #include "Metric.h"
 
@@ -32,18 +31,18 @@ public :
   void uniformQuantification(unsigned int);
 
 protected:
-  virtual void setNodeValue_handler(const node n);
-  virtual void setEdgeValue_handler(const edge e);
-  virtual void setAllNodeValue_handler();
-  virtual void setAllEdgeValue_handler();
+  virtual void setNodeValue_handler(const node n, const DoubleType::RealType &);
+  virtual void setEdgeValue_handler(const edge e, const DoubleType::RealType &);
+  virtual void setAllNodeValue_handler(const DoubleType::RealType &);
+  virtual void setAllEdgeValue_handler(const DoubleType::RealType &);
   void reset_handler();
   void recompute_handler();
   void clone_handler(PropertyProxy<DoubleType,DoubleType> &);
 
 private:
-  stdext::hash_map<int ,double> maxN,minN,maxE,minE;
-  stdext::hash_map<int,bool> minMaxOkNode;
-  stdext::hash_map<int,bool> minMaxOkEdge;
+  stdext::hash_map<unsigned long, double> maxN,minN,maxE,minE;
+  stdext::hash_map<unsigned long, bool> minMaxOkNode;
+  stdext::hash_map<unsigned long, bool> minMaxOkEdge;
   void computeMinMaxNode(SuperGraph *sg=0);
   void computeMinMaxEdge(SuperGraph *sg=0);
 };
