@@ -19,7 +19,7 @@ enum State { VECT=0, HASH=1 };
 
 class ImpossibleOperation : public std::exception {
 };
-
+#ifndef DOXYGEN_NOTFOR_DEVEL
 //===================================================================
 template <typename TYPE> 
 class IteratorVector : public Iterator<unsigned int> {
@@ -77,6 +77,7 @@ class IteratorHash : public Iterator<unsigned int> {
   stdext::hash_map<unsigned int,TYPE> *hData;
   typename stdext::hash_map<unsigned int,TYPE>::const_iterator it;
 };
+#endif
 //===================================================================
 template <typename TYPE> 
 class MutableContainer {
@@ -86,8 +87,18 @@ public:
   ~MutableContainer();
   void setAll(const TYPE &value);
   void set(const unsigned int i,const TYPE &value);  
-  typename ReturnType<TYPE>::Value get(const unsigned int i) const;
+  /**
+   * This function return a reference instead of a copy in order to minimize the
+   * the number copy of objects, user must be awer that calling the set function can 
+   * devalidate this reference.
+   */
+  const typename ReturnType<TYPE>::Value get(const unsigned int i) const;
   Iterator<unsigned int>* findAll(const TYPE &value) const throw (ImpossibleOperation) ;
+  /**
+   * This function is available only for optimisation purpose, one must be sure the 
+   * the referenced element is not the default value. Use this function extremely carefully
+   */
+  TYPE & getReference(const unsigned int i);
 private:
   MutableContainer(const MutableContainer<TYPE> &){}
   void operator=(const MutableContainer<TYPE> &){}
@@ -186,7 +197,7 @@ void MutableContainer<TYPE>::set(const unsigned int i,const TYPE &value) {
   //Test if after insertion we need to resize
   if (!compressing && value != defaultValue) {
     compressing = true;
-    compress (i<?minIndex, i>?maxIndex, elementInserted);
+    compress (std::min(i,minIndex), std::max(i,maxIndex), elementInserted);
     compressing = false;
   }
   
@@ -246,14 +257,14 @@ void MutableContainer<TYPE>::set(const unsigned int i,const TYPE &value) {
       std::cerr << __PRETTY_FUNCTION__ << "unexpected state value (serious bug)" << std::endl;
       break; 
     }
-    maxIndex >?= i;
-    minIndex <?= i;
+    maxIndex = std::max(maxIndex, i);
+    minIndex = std::min(minIndex, i);
   }
 }
 //===================================================================
 //const TYPE &  MutableContainer<TYPE>::get(unsigned int i) const {
 template <typename TYPE>   
-typename ReturnType<TYPE>::Value MutableContainer<TYPE>::get(const unsigned int i) const {
+const typename ReturnType<TYPE>::Value MutableContainer<TYPE>::get(const unsigned int i) const {
   //  cerr << __PRETTY_FUNCTION__ << endl;
   if (maxIndex == UINT_MAX) return defaultValue;
   typename stdext::hash_map<unsigned int,TYPE>::iterator it;
@@ -277,6 +288,12 @@ typename ReturnType<TYPE>::Value MutableContainer<TYPE>::get(const unsigned int
   }
 }
 //===================================================================
+//const TYPE &  MutableContainer<TYPE>::get(unsigned int i) const {
+template <typename TYPE>   
+TYPE & MutableContainer<TYPE>::getReference(const unsigned int i) {
+  return (TYPE &) get(i);
+}
+//===================================================================
 template <typename TYPE> 
 void MutableContainer<TYPE>::vecttohash() {
   //  std::cerr << __FUNCTION__ << std::endl << std::flush;
@@ -288,8 +305,8 @@ void MutableContainer<TYPE>::vecttohash() {
   for (unsigned int i=minIndex; i<=maxIndex; ++i) {
     if ((*vData)[i - minIndex] != defaultValue) {
       (*hData)[i] = (*vData)[i - minIndex];
-      newMaxIndex >?= i;
-      newMinIndex <?= i;
+      newMaxIndex = std::max(newMaxIndex, i);
+      newMinIndex = std::min(newMinIndex, i);
       ++elementInserted;
     }
   }
