@@ -8,6 +8,7 @@ struct SuperGraph;
 
 /** \addtogroup graphs */ 
 /*@{*/
+/// Observer for Graph
 /**
  * The Observer pattern is described in the lecture notes and pp293-304 
  * of Design Patterns by Gamma, Helm, Johnson, and Vlissides. It is a 
@@ -30,7 +31,7 @@ namespace std {
   template <>
   struct less<GraphObserver *> {
     size_t operator()(const GraphObserver * obs1,const GraphObserver *obs2) const {
-      return (unsigned)obs1<(unsigned)obs2;
+      return (unsigned long)obs1<(unsigned long)obs2;
     }
   };
 }
@@ -39,13 +40,14 @@ namespace std {
 /*@{*/
 /**
  */
+/// Observable object for graph
 class ObservableGraph {
  public:
   virtual ~ObservableGraph() {}
   /**
    * Register a new observer
    */
-  void addObserver(GraphObserver *);
+  void addObserver(GraphObserver *) const;
   /**
    * Return the number of observers
    */
@@ -53,7 +55,7 @@ class ObservableGraph {
   /**
    * Remove an observer
    */
-  void removeObserver(GraphObserver *);
+  void removeObserver(GraphObserver *) const;
   /**
    * Remove all observers
    */
@@ -66,11 +68,11 @@ class ObservableGraph {
   void notifyDelEdge(SuperGraph *,const edge e);
   void notifyReverseEdge(SuperGraph *,const edge e);
   void notifyDestroy(SuperGraph *);
-  std::set<GraphObserver*> observers;
+  mutable std::set<GraphObserver*> observers;
 };
 /*@}*/
 
-inline void ObservableGraph::addObserver(GraphObserver *obs) {
+inline void ObservableGraph::addObserver(GraphObserver *obs) const {
   observers.insert(obs); 
 }
 
@@ -78,7 +80,7 @@ inline unsigned int ObservableGraph::countObservers() {
   return observers.size(); 
 }
 
-inline void ObservableGraph::removeObserver(GraphObserver *item) {  
+inline void ObservableGraph::removeObserver(GraphObserver *item) const{  
   observers.erase(item);
 }
 
