@@ -1,5 +1,5 @@
 //-*-c++-*-
-/**
+/*
  Author: David Auber
  Email : auber@labri.fr
  Last modification : 20/08/2001
@@ -12,13 +12,19 @@
 #ifndef TULIPPLUGIN_H
 #define TULIPPLUGIN_H
 #include <string>
-/**Common interface for plug-ins.*/
+
+/** Common interface for plug-ins.*/
 class Plugin {
 public:
+  virtual ~Plugin(){}
   /**Return the name of the plug-in, be careful, 
      this name must be unique, if two plug-ins have the same name
      only the latest loaded will be available*/
   virtual  std::string getName() const=0;
+  /* Return the group name of the plug-in,
+     a string with subgroup names separated by ::
+     ex: trees::planar trees */
+  virtual std::string getGroup() const=0;
   /**Return the author of the plug-in*/
   virtual  std::string getAuthor() const=0;
   /**Return the date of creation of the plug-in*/
