@@ -1,6 +1,6 @@
 //-*-c++-*-
 
-/**
+/*
  Author: David Auber
  Email : auber@labri.fr
  Last modification : 20/08/2001
@@ -37,8 +37,6 @@ public:
   virtual bool run() = 0;
   ///
   virtual bool check(std::string &) = 0;
-  ///
-  virtual void reset() = 0;
 };
 
 ///
@@ -54,15 +52,9 @@ public :
   ///
   virtual ~Property(){}
   ///
-  virtual typename Tnode::RealType getNodeValue(const node ) {return Tnode::defaultValue();}
-  ///
-  virtual typename Tedge::RealType getEdgeValue(const edge ) {return Tedge::defaultValue();}
-  ///
   virtual bool run() {return true;}
   ///
   virtual bool check(std::string &) {return true;}
-  ///
-  virtual void reset() {}
 
 protected:
   SuperGraph *superGraph;
