@@ -7,7 +7,6 @@
 #endif
 
 #include "PropertyProxy.h"
-#include "MethodFactory.h"
 #include "TemplateFactory.h"
 #include "Selection.h"
 
@@ -26,7 +25,8 @@ public :
   void reverse();
   ///reverse all the direction of edges of the visible graph which are true in this Selection Proxy
   void reverseEdgeDirection();
-
+  Iterator<node> *getNodesEqualTo(const bool val, SuperGraph * = 0);
+  Iterator<edge> *getEdgesEqualTo(const bool val, SuperGraph * = 0);
 protected:
   void reset_handler();
 };
