@@ -32,20 +32,22 @@ class SuperGraph;
 
 /** \addtogroup graph_test */ 
 /*@{*/
+/**
+ * class for testing if the graph is simple (ie no self loops and  no multiple or parallel edges)
+ */
 class TLP_SCOPE SimpleTest : public GraphObserver {
  public: 
   static bool isSimple(SuperGraph *graph);
-
+  static void makeSimple(SuperGraph* graph, std::vector<edge> &removed);
+  static bool simpleTest(SuperGraph *graph, std::vector<edge> *multipleEdges=0, std::vector<edge> *loops=0);
  private:
   SimpleTest();
-  bool compute(SuperGraph *graph);
-  bool setResult(SuperGraph *graph, bool result);
   void addEdge(SuperGraph *, const edge);
   void delEdge(SuperGraph *, const edge);
   void destroy(SuperGraph *);
   void deleteResult(SuperGraph *graph);
   static SimpleTest *instance;
-  stdext::hash_map<unsigned int, bool> resultsBuffer;
+  stdext::hash_map<unsigned long, bool> resultsBuffer;
 };
 /*@}*/
 #endif
