@@ -7,7 +7,6 @@
 #endif
 
 #include "PropertyProxy.h"
-#include "MethodFactory.h"
 #include "TemplateFactory.h"
 #include "Sizes.h"
 
@@ -30,18 +29,18 @@ public :
   void copy( const node, const node, PProxy * );
   void copy( const edge, const edge, PProxy * );
   void scale( const tlp::Vector<float,3>&, SuperGraph *graph=0 );
-
+  void scale( const tlp::Vector<float,3>&, Iterator<node> *, Iterator<edge> *);
 protected:
   void reset_handler();
   void resetMinMax();
-  virtual void setNodeValue_handler(const node n);
-  virtual void setEdgeValue_handler(const edge e);
-  virtual void setAllNodeValue_handler();
-  virtual void setAllEdgeValue_handler();
+  virtual void setNodeValue_handler(const node n, const SizeType::RealType &);
+  virtual void setEdgeValue_handler(const edge e, const SizeType::RealType &);
+  virtual void setAllNodeValue_handler( const SizeType::RealType &);
+  virtual void setAllEdgeValue_handler( const SizeType::RealType &);
 
 private:
-  stdext::hash_map<int,Size> max,min;
-  stdext::hash_map<int,bool> minMaxOk;
+  stdext::hash_map<unsigned long,Size> max,min;
+  stdext::hash_map<unsigned long,bool> minMaxOk;
   void computeMinMax(SuperGraph * sg=NULL);
 };
 /*@}*/
