@@ -1,8 +1,8 @@
 //-*-c++-*-
 #ifndef _TLPSTLFUNCTIONS_H
 #define _TLPSTLFUNCTIONS_H
-
-class SuperGraph;
+//#include "SuperGraph.h"
+//#include "MetricProxy.h"
 class MetricProxy;
 class node;
 class edge;
@@ -12,7 +12,7 @@ class edge;
  */
 class LessByMetric {
  public:
-  LessByMetric(MetricProxy *m):metric(m){}
+  LessByMetric(MetricProxy *metric):metric(metric){}
   bool operator() (node n1,node n2);
   bool operator() (edge e1,edge e2);
 private:
