@@ -2,6 +2,8 @@
 #ifndef TULIP_SUPERGRAPHABSTRACT_H
 #define TULIP_SUPERGRAPHABSTRACT_H
 
+#ifndef DOXYGEN_NOTFOR_USER
+
 #include <set>
 #include "SuperGraph.h"
 #include "Reflect.h"
@@ -52,12 +54,15 @@ public:
 
 protected:
   void setFather(SuperGraph *);
+  PropertyManager *propertyContainer;
 
 private:
   DataSet attributes;
   SuperGraph *father;
   std::set<SuperGraph *> subgraphs;
-  PropertyManager *propertyContainer;
+
 };
 
+#endif // DOXYGEN_NOTFOR_USER
+
 #endif
