@@ -1,5 +1,5 @@
 //-*-c++-*-
-/**
+/*
  Author: David Auber
  Email : auber@labri.fr
  Last modification : 01/09/2003
@@ -22,16 +22,19 @@
 #include <ext/hash_set>
 #endif
 #include "tulip/ObservableGraph.h"
+#include "tulip/MutableContainer.h"
 
 class SuperGraph;
 class SelectionProxy;
 
 /** \addtogroup graph_test */ 
 /*@{*/
+/// Class for testing if the graph is a tree
 class TLP_SCOPE TreeTest : private GraphObserver {
 public:
   static bool isTree(SuperGraph *graph);
-
+  static bool isTopologicalTree(SuperGraph *graph);
+  static void makeRootedTree(SuperGraph *graph, node root);
 private:
   bool compute(SuperGraph *);
   void addEdge(SuperGraph *,const edge);
@@ -42,7 +45,10 @@ private:
   void destroy(SuperGraph *);
   TreeTest();
   static TreeTest * instance;
-  stdext::hash_map<unsigned int,bool> resultsBuffer;
+  bool isTopologicalTree (SuperGraph *graph, node curRoot, node cameFrom,
+			  MutableContainer<bool> &visited);
+  void makeRootedTree (SuperGraph *graph, node curRoot, node cameFrom);
+  stdext::hash_map<unsigned long,bool> resultsBuffer;
 };
 /*@}*/
 #endif
