@@ -2,6 +2,10 @@
 #ifndef TYPES_H
 #define TYPES_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <vector>
 #include <string>
 #include <list>
@@ -11,6 +15,7 @@
 #include "Coord.h"
 #include "Size.h"
 #include "Color.h"
+#include "StringCollection.h"
 
 class SuperGraph;
 
@@ -26,7 +31,7 @@ public:
   ~Type();
 };
 
-class MetaGraphType:public Type {
+class TLP_SCOPE MetaGraphType:public Type {
 public:
   typedef SuperGraph* RealType;
   static MetaGraphType::RealType undefineValue();
@@ -36,9 +41,7 @@ public:
   static bool fromString( RealType & v, const std::string & s );
 };
 
-
-///
-class DoubleType:public Type {
+class TLP_SCOPE DoubleType:public Type {
 public:
   typedef double RealType;
   static double undefineValue();
@@ -48,9 +51,7 @@ public:
   static bool fromString( RealType & v, const std::string & s );
 };
 
-
-///
-class IntType:public Type
+class TLP_SCOPE IntType:public Type
 {
 public:
   typedef int RealType;
@@ -61,9 +62,7 @@ public:
   static bool fromString( RealType & v, const std::string & s );
 };
 
-
-///
-class BooleanType:public Type {
+class TLP_SCOPE BooleanType:public Type {
 public:
   typedef bool RealType;
   static bool undefineValue();
@@ -73,9 +72,7 @@ public:
   static bool fromString( RealType & v, const std::string & s );
 };
 
-
-///
-class LineType:public Type
+class TLP_SCOPE LineType:public Type
 {
 public:
   typedef std::vector<Coord> RealType;
@@ -86,11 +83,9 @@ public:
   static bool fromString( RealType & v, const std::string & s );
 };
 
-
-///
-class PointType:public Type {
+class TLP_SCOPE PointType:public Type {
 public:
-  typedef  Coord RealType;
+  typedef Coord RealType;
   static Coord undefineValue();
   static Coord defaultValue();
   static void del(PointType::RealType element);
@@ -98,9 +93,7 @@ public:
   static bool fromString( RealType & v, const std::string & s );
 };
 
-
-///
-class SizeType:public Type {
+class TLP_SCOPE SizeType:public Type {
 public:
   typedef  Size RealType;
   static Size undefineValue();
@@ -110,9 +103,7 @@ public:
   static bool fromString( RealType & v, const std::string & s );
 };
 
-
-///
-class StringType:public Type {
+class TLP_SCOPE StringType:public Type {
 public:
   typedef std::string RealType;
   static std::string undefineValue();
@@ -122,9 +113,7 @@ public:
   static bool fromString( RealType & v, const std::string & s );
 };
 
-
-///
-class ColorType:public Type {
+class TLP_SCOPE ColorType:public Type {
 public:
   typedef Color RealType;
   static Color undefineValue();
@@ -134,6 +123,16 @@ public:
   static bool fromString( RealType & v, const std::string & s );
 };
 
+class TLP_SCOPE StringCollectionType: public Type {
+public:
+  typedef StringCollection RealType;
+  static  RealType         undefineValue();
+  static  RealType         defaultValue();
+  static  void             del(StringCollectionType::RealType element);
+  static  std::string      toString(const RealType& sourceVector);
+  static  bool             fromString( RealType& v, const std::string& s);
+};
+
 
 /*@}*/
 #endif
