@@ -25,8 +25,8 @@ namespace tlp {
    * Fixed size and provide Mathematical operation. Mathematical 
    * operators must be defined for Obj. 
    *
-   * Author : <a href="mailto:auber@tulip-software.org>David Auber</A>
-   * Version 0.0.1 24/01/2003 
+   * \author : David Auber auber@tulip-software.org
+   * \version 0.0.1 24/01/2003 
    */
   TEMPLATEVECTOR
     class TLP_SCOPE Vector:public Array<Obj,SIZE> {
@@ -41,6 +41,8 @@ namespace tlp {
     inline VECTOR & operator+=(const VECTOR &);
     inline VECTOR & operator-=(const Obj &);
     inline VECTOR & operator-=(const VECTOR &);
+    inline VECTOR & operator^=(const VECTOR &);
+    
     inline VECTOR operator+(const VECTOR &) const;
     inline VECTOR operator+(const Obj &) const;
     inline VECTOR operator-(const VECTOR &) const;
@@ -50,6 +52,7 @@ namespace tlp {
     inline VECTOR operator/(const VECTOR &) const;
     inline VECTOR operator/(const Obj &) const;
     inline VECTOR operator^(const VECTOR &) const;
+
     inline bool operator!=(const VECTOR &) const;
     inline bool operator==(const VECTOR &) const;
     inline VECTOR & fill(const Obj &obj);
