@@ -12,10 +12,10 @@ struct TLP_SCOPE WithParameter {
   ///
   StructDef getParameters();
   ///
-  template<typename Ty> void addParameter(	std::string str,
-  											const char * inHelp=0,
-  											std::string inDefValue = std::string()	)
-  											{ parameters.template add<Ty>(str,inHelp,inDefValue); }
+  template<typename Ty> void addParameter(const char* str,
+					  const char* inHelp=0,
+					  const char* inDefValue = 0)
+  { parameters.template add<Ty>(str,inHelp,inDefValue); }
 protected:
   ///
   StructDef parameters;
