@@ -45,7 +45,7 @@ tlp::Circle<Obj> tlp::enclosingCircle(const Circle<Obj> &c1,const Circle<Obj> &c
   Vector<Obj,2> dir=c2-c1;
   Obj n=dir.norm();
   if (n==0)
-    return Circle<Obj>(c1,c1.radius >? c2.radius);
+    return Circle<Obj>(c1, std::max(c1.radius,  c2.radius));
   dir/=n;
   Vector<Obj,2> ext1=c1-dir*c1.radius;
   Vector<Obj,2> ext2=c2+dir*c2.radius;
@@ -64,16 +64,16 @@ tlp::Circle<Obj> tlp::lazyEnclosingCircle(const std::vector<Circle<Obj> > & circ
   boundingBox[3]=(*it)[1]+(*it).radius;
   ++it;
   for (;it!=circles.end();++it) {
-    boundingBox[0]=boundingBox[0] <? ((*it)[0]-(*it).radius);
-    boundingBox[1]=boundingBox[1] <? ((*it)[1]-(*it).radius);
-    boundingBox[2]=boundingBox[2] >? ((*it)[0]+(*it).radius);
-    boundingBox[3]=boundingBox[3] >? ((*it)[1]+(*it).radius);
+    boundingBox[0] = std::min(boundingBox[0] , ((*it)[0]-(*it).radius));
+    boundingBox[1] = std::min(boundingBox[1] , ((*it)[1]-(*it).radius));
+    boundingBox[2] = std::max(boundingBox[2] , ((*it)[0]+(*it).radius));
+    boundingBox[3] = std::max(boundingBox[3] , ((*it)[1]+(*it).radius));
   }
 
   tlp::Vector<Obj,2> center;
   center[0]=(boundingBox[0]+boundingBox[2])/2.;
   center[1]=(boundingBox[1]+boundingBox[3])/2.;
-  Obj radius = ((boundingBox[2]-boundingBox[0])/2. ) >? ( (boundingBox[3]-boundingBox[1])/2. );
+  Obj radius = std::max( (boundingBox[2]-boundingBox[0])/2., (boundingBox[3]-boundingBox[1])/2. );
   tlp::Circle<Obj> result(center,radius);
   //compute circle hull
   for (typename std::vector< tlp::Circle<Obj> >::const_iterator it=circles.begin();it!=circles.end();++it) 
