@@ -1,6 +1,7 @@
 #ifndef HASH_STRING_H
 #define HASH_STRING_H
 
+#ifndef DOXYGEN_NOTFOR_DEVEL
 #include <string>
 
 namespace stdext {
@@ -12,8 +13,8 @@ namespace stdext {
    * \brief provides string hash method 
    *
    *
-   * Author : <a href="mailto:auber@tulip-software.org>David Auber</A>
-   * Version 0.0.1 24/01/2003 
+   * \author : David Auber auber@tulip-software.org
+   * \version 0.0.1 24/01/2003 
    */
   template<> struct hash<const std::string>{
     size_t operator()(const std::string &s) const {return hash<const char *>()(s.c_str()); }
@@ -24,4 +25,5 @@ namespace stdext {
    /*@}*/
 }
 
+#endif //DOXYGEN_NOTFOR_DEVEL
 #endif //HASH_STRING_H
