@@ -5,7 +5,6 @@
 #include "tulip/Observable.h"
 #include "tulip/Colors.h"
 #include "tulip/PropertyProxy.h"
-#include "tulip/MethodFactory.h"
 
 using namespace std;
 
@@ -15,6 +14,7 @@ ColorsProxy::ColorsProxy (SuperGraph *graph):PropertyProxy<ColorType,ColorType,
 }
 //==============================
 ColorsProxy::~ColorsProxy() {
+  notifyDestroy();
 }    
 //=================================================================================
 PProxy* ColorsProxy::clonePrototype(SuperGraph * g, std::string n) {
