@@ -1,7 +1,4 @@
 //-*-c++-*-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
 
 #include <cassert>
 #include <cmath>
@@ -9,9 +6,10 @@
 
 #include "tulip/Coord.h"
 
-float Coord::dist(const Coord &c) const {return sqrt((v[0]-c.v[0])*(v[0]-c.v[0])+(v[1]-c.v[1])*(v[1]-c.v[1])+(v[2]-c.v[2])*(v[2]-c.v[2]));}
-float Coord::norm() const {return sqrt(v[0]*v[0]+v[1]*v[1]+v[2]*v[2]);}
+//float Coord::dist(const Coord &c) const {return sqrt(((*this)[0]-c[0])*((*this)[0]-c[0])+((*this)[1]-c[1])*((*this)[1]-c[1])+((*this)[2]-c[2])*((*this)[2]-c[2]));}
+//float Coord::norm() const {return sqrt((*this)[0]*(*this)[0]+(*this)[1]*(*this)[1]+(*this)[2]*(*this)[2]);}
 
+/*
 std::ostream & operator<< (std::ostream &os, const Coord &c) {
   os << '(';
   os << c.v[0];
@@ -47,5 +45,5 @@ failed:
   is.setstate( std::ios::failbit );
   return is;  
 }
-
+*/
 
