@@ -4,6 +4,16 @@
 
 #include "tulip/MapIterator.h"
 
+using namespace std;
+
+edge tlp::nextFaceEdge(SuperGraph *g, edge e, node n) {
+  EdgeMapIterator it(g, e, n);
+  edge result;
+  if (it.hasNext())
+    result = it.next();
+  return result;
+}
+
 NodeMapIterator::NodeMapIterator(SuperGraph *sg, node source, node target) {
   assert(cloneIt.empty());
   bool start=true;
@@ -39,33 +49,26 @@ bool NodeMapIterator::hasNext() {
 //=========================================
 
 EdgeMapIterator::EdgeMapIterator(SuperGraph *sg, edge source, node target) {
-  assert(cloneIt.empty());
-  bool start=true;
-  Iterator<edge> *itIn=sg->getInOutEdges(target);
-  for (;itIn->hasNext();) {
-    edge tmp=itIn->next();
-    if (start && tmp==source) {
-      start=false;
-      itStl=cloneIt.begin();
-    }
-    else {
-      if (start)
-	cloneIt.push_back(tmp);
-      else 
-	cloneIt.insert(itStl,tmp);
-    }
-  } delete itIn;
-  itStl=cloneIt.begin();
+  adj.resize(sg->deg(target));
+  finished = false;
+  treat =0;
+  pos = 0;
+  Iterator<edge> *it=sg->getInOutEdges(target);
+  while (it->hasNext()) {
+    edge e = it->next();
+    if (e == source) pos = treat + 1;
+    adj[treat++] = e;
+  } delete it;
 }
 
 EdgeMapIterator::~EdgeMapIterator(){}
 
 edge EdgeMapIterator::next() {
-  edge tmp=*itStl;
-  ++itStl;
-  return tmp;
+  --treat;
+  pos %= adj.size();
+  return adj[pos++];
 }
 
 bool EdgeMapIterator::hasNext() {
-  return (itStl!=cloneIt.end());
+  return (treat>0);
 }
