@@ -56,7 +56,7 @@ string StructDef::getDefValue( string str ) const {
 #undef TN
 #define	TN( T )	typeid(T).name()
 
-bool StructDef::buildDefaultDataSet(DataSet &ioDataSet, SuperGraph *inG) {
+void StructDef::buildDefaultDataSet(DataSet &ioDataSet, SuperGraph *inG) {
   Iterator< pair<string,string> > * defIt;
   defIt = getField();
 
@@ -94,6 +94,13 @@ bool StructDef::buildDefaultDataSet(DataSet &ioDataSet, SuperGraph *inG) {
       ioDataSet.set( name, v );
     }
     // fp
+    else if( tname == TN(double) ) {
+      double v;
+      bool res = DoubleType::fromString( v, defv );
+      assert( res );
+      if( res )
+	ioDataSet.set( name, (double)v );
+    }
     else if( tname == TN(float) ) {
       double v;
       bool res = DoubleType::fromString( v, defv );
@@ -112,7 +119,7 @@ bool StructDef::buildDefaultDataSet(DataSet &ioDataSet, SuperGraph *inG) {
       assert( res );
       if( res ) {
 	ioDataSet.set( name, v );
-	cout << v;
+	//cout << v;
       }
     }
     // Size
