@@ -1,8 +1,4 @@
 //-*-c++-*-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "tulip/Selection.h"
 #include "tulip/SuperGraph.h"
 #include "tulip/SelectionProxy.h"
