@@ -1,6 +1,5 @@
 //-*-c++-*-
 
-#include "tulip/MethodFactory.h"
 #include "tulip/StringProxy.h"
 #include "tulip/PluginContext.h"
 #include "tulip/Observable.h"
@@ -14,6 +13,7 @@ StringProxy::StringProxy (SuperGraph *graph):PropertyProxy<StringType,StringType
 }
   
 StringProxy::~StringProxy() {
+  notifyDestroy();
 }
 
 void StringProxy::reset_handler() {
