@@ -1,12 +1,15 @@
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
 
 #include "tulip/SuperGraph.h"
 
 using namespace std;
 
+#ifdef _WIN32 
+#ifdef DLL_EXPORT
 IdManager SuperGraph::idManager;
+#endif
+#else
+IdManager SuperGraph::idManager;
+#endif
 
 ostream & operator << (ostream &os,const SuperGraph *sp) {
   os << ";(nodes <node_id> <node_id> ...)" << endl;
@@ -27,7 +30,3 @@ ostream & operator << (ostream &os,const SuperGraph *sp) {
   os << endl;
   return os;
 }
-
-
-
-
