@@ -4,15 +4,10 @@
 
 #include <tulip/TulipPlugin.h>
 
-class EqualValueClustering:public Clustering
-{ 
+class EqualValueClustering:public Clustering { 
 public:
   EqualValueClustering(ClusterContext);
-  ~EqualValueClustering();
   bool run();
-  bool check(std::string &);
-  void reset();
-
 };
 
 #endif
