@@ -4,8 +4,9 @@
 
 #include <tulip/TulipPlugin.h>
 
-class QuotientClustering:public Clustering
-{ 
+/** \addtogroup clustering */
+/*@{*/
+class QuotientClustering:public Clustering { 
 public:
   QuotientClustering(ClusterContext);
   ~QuotientClustering();
@@ -14,7 +15,7 @@ public:
   void reset();
 
 };
-
+/*@}*/
 #endif
 
 
