@@ -15,22 +15,22 @@ using namespace std;
 using namespace tlp;
 
 void RGBtoHSV( float r, float g, float b, float *h, float *s, float *v ) {
-  float min, max, delta;
-  min = r <? g <? b; //MIN( MIN( r, g) , b );
-  max = r >? g >? b; //MAX( MAX( r, g) , b );
-  *v = max;                               // v
-  delta = max - min;
-  if( max != 0 )
-    *s = delta / max;               // s
+  float theMin, theMax, delta;
+  theMin = std::min(std::min(r, g), b); //MIN( MIN( r, g) , b );
+  theMax = std::max(std::max(r, g), b); //MAX( MAX( r, g) , b );
+  *v = theMax;                               // v
+  delta = theMax - theMin;
+  if( theMax != 0 )
+    *s = delta / theMax;               // s
   else {
     // r = g = b = 0                // s = 0, v is undefined
     *s = 0;
     *h = -1;
     return;
   }
-  if( r == max )
+  if( r == theMax )
     *h = ( g - b ) / delta;         // between yellow & magenta
-  else if( g == max )
+  else if( g == theMax )
     *h = 2 + ( b - r ) / delta;     // between cyan & yellow
   else
     *h = 4 + ( r - g ) / delta;     // between magenta & cyan
@@ -120,24 +120,24 @@ namespace {
   };
 }
 
-class MetricMapping: public Colors { 
+class MetricColorMapping: public Colors { 
 private:
   MetricProxy *entryMetric;
   int colorModel;
   Color color1;
   Color color2;
-  Vector<float,3> deltaRGB;
+  Vector<float,4> deltaRGBA;
 
 public:
-  MetricMapping(const PropertyContext &context):Colors(context){
+  MetricColorMapping(const PropertyContext &context):Colors(context){
     addParameter<MetricProxy>("property",paramHelp[0],"viewMetric");
     addParameter<int>("colormodel",paramHelp[1],"1");
     addParameter<bool>("type",paramHelp[4],"true");
-    addParameter<Color>("color1",paramHelp[2],"(255,255,0,255)");
-    addParameter<Color>("color2",paramHelp[3],"(0,0,255,255)");
+    addParameter<Color>("color1",paramHelp[2],"(255,255,0,128)");
+    addParameter<Color>("color2",paramHelp[3],"(0,0,255,228)");
   }
   //=========================================================
-  ~MetricMapping(){}
+  ~MetricColorMapping(){}
   //=========================================================
   Color getColor(double value, double range) {
     if (range==0) range = 1;
@@ -149,27 +149,27 @@ public:
       s=1;
       h=55.0+value*300.0/range;
       HSVtoRGB(&r,&g,&b,h,s,v);
-      return Color((int)(r*255.0f),(int)(g*255.0f),(int)(b*255.0f),0); 
+      return Color((int)(r*255.0f),(int)(g*255.0f),(int)(b*255.0f),color1[3] + (int)deltaRGBA[3]*value); 
       break;
     case 1: //RGB interpolation
-      Vector<float,3> tmp(deltaRGB);
-      tmp*=value;
+      Vector<float,4> tmp(deltaRGBA);
+      tmp *= value;
       return  Color((int)(tmp[0]+color1[0]),
 		    (int)(tmp[1]+color1[1]),
 		    (int)(tmp[2]+color1[2]),
-		    0); 
+		    (int)(tmp[3]+color1[3]));
       break;
     }
   }
   //=========================================================
   void computeEdgeColor() {
     double minE,maxE;
-    minE=entryMetric->getEdgeMin();
-    maxE=entryMetric->getEdgeMax();
-    for (int i=0;i<3;++i)
-      deltaRGB[i]=double(color2[i]-color1[i]);
+    minE = entryMetric->getEdgeMin(superGraph);
+    maxE = entryMetric->getEdgeMax(superGraph);
+    for (int i=0;i<4;++i)
+      deltaRGBA[i]=double(color2[i]-color1[i]);
     if (maxE!=minE)
-      deltaRGB/=double(maxE-minE);
+      deltaRGBA/=double(maxE-minE);
     Iterator<edge> *itE=superGraph->getEdges();
     while(itE->hasNext()) {
       edge ite=itE->next();
@@ -180,12 +180,12 @@ public:
   //=========================================================
   void computeNodeColor() {
     double minN,maxN;
-    minN=entryMetric->getNodeMin();
-    maxN=entryMetric->getNodeMax();
-    for (int i=0;i<3;++i)
-      deltaRGB[i]=double(color2[i]-color1[i]);
+    minN=entryMetric->getNodeMin(superGraph);
+    maxN=entryMetric->getNodeMax(superGraph);
+    for (int i=0;i<4;++i)
+      deltaRGBA[i]=double(color2[i]-color1[i]);
     if (maxN!=minN)
-      deltaRGB/=double(maxN-minN);
+      deltaRGBA/=double(maxN-minN);
     Iterator<node> *itN=superGraph->getNodes();
     while(itN->hasNext()) {
       node itn=itN->next();
@@ -195,36 +195,45 @@ public:
   }
   //=========================================================
   bool run() {
-    MetricProxy* metricS=superGraph->getProperty<MetricProxy>("viewMetric");
+    //    cerr << __PRETTY_FUNCTION__ << endl;
+    MetricProxy* metricS = superGraph->getProperty<MetricProxy>("viewMetric");
     colorModel=1;
-    color1.set(255,255,0);
-    color2.set(0,0,255);
+    color1.set(255,255,0,128);
+    color2.set(0,0,255,228);
     bool mappingType = true;
     if ( dataSet!=0 ) {
-      dataSet->get("property",metricS);
-      dataSet->get("colormodel",colorModel);
-      dataSet->get("color1",color1);
-      dataSet->get("color2",color2);
-      dataSet->get("type",mappingType);
+      dataSet->get("property", metricS);
+      dataSet->get("colormodel", colorModel);
+      dataSet->get("color1", color1);
+      dataSet->get("color2", color2);
+      dataSet->get("type", mappingType);
     }
     if (mappingType) {
       entryMetric = metricS;
+      /*
+	Iterator<node> *itN = superGraph->getNodes();
+	while(itN->hasNext()) {
+	node n = itN->next();
+	entryMetric->setNodeValue(n, log(1+entryMetric->getNodeValue(n)));
+	} delete itN;
+      */
     }
     else {
-      MetricProxy *tmp=superGraph->getLocalProperty<MetricProxy>("tmpUni");
-      *tmp=*metricS;
+      MetricProxy *tmp= new MetricProxy(superGraph);
+      *tmp = *metricS;
       tmp->uniformQuantification(300);
       entryMetric = tmp;
     }
     computeNodeColor();
     computeEdgeColor();
-    if (!mappingType) superGraph->delLocalProperty("tmpUni");
+    if (!mappingType) delete entryMetric;
     return true;
   }
   //=========================================================
   bool check(string &err){
+    //    cerr << __PRETTY_FUNCTION__ << endl;
     return true;
   }
 };
 
-COLORSPLUGIN(MetricMapping,"Metric Mapping","Auber","04/07/2003","0","0","1");
+COLORSPLUGIN(MetricColorMapping,"Metric Mapping","Auber","04/07/2003","0","0","1");
