@@ -22,6 +22,7 @@ private:
   GLuint LList;
   bool listOk;
   void drawCube(GLenum);
+  void drawCubeSimple(GLenum);
 };
 
 GLYPHPLUGIN(CubeOutLined, "CubeOutLined", "David Auber", "09/07/2002", "Textured cubeOutLined", "1", "1", 1);
@@ -31,38 +32,51 @@ CubeOutLined::CubeOutLined(GlyphContext *gc): Glyph(gc),listOk(false) {
 }
 
 CubeOutLined::~CubeOutLined() {
-  if (listOk)
-    if (glIsList(LList)) glDeleteLists(LList, 1);
+  if (listOk) {
+    if (glIsList(LList)) glDeleteLists(LList, 2);
+  }
 }
 
 void CubeOutLined::draw(node n) {
+  //  cerr << __PRETTY_FUNCTION__ << endl;
+  if (!listOk) {
+    LList = glGenLists( 2 );
+    glNewList( LList, GL_COMPILE );
+    drawCube(GL_QUADS);
+    glEndList();
+    glNewList( LList + 1, GL_COMPILE );
+    //    setMaterial(Color(0,0,0,255));
+    drawCubeSimple(GL_LINE_LOOP);
+    glEndList();
+    GLenum error = glGetError();
+    if ( error != GL_NO_ERROR)
+      cerr << "Open GL Error : " << error << " in " << __PRETTY_FUNCTION__ << endl;
+    listOk=true;
+  }
+  assert(glIsList(LList));
   setMaterial(glGraph->elementColor->getNodeValue(n));
   string texFile = glGraph->elementTexture->getNodeValue(n);
   if (texFile != "") {
     if (glGraph->activateTexture(texFile))
       setMaterial(Color(255,255,255,0));
   }
-  if (!listOk) {
-    LList = glGenLists( 1 );
-    glNewList( LList, GL_COMPILE );
-    drawCube(GL_QUADS);
-    setMaterial(Color(0,0,0,255));
-    drawCube(GL_LINE_LOOP);
-    glEndList();
-    GLenum error=glGetError();
-    if ( error != GL_NO_ERROR)
-      cerr << "Open GL Error : " << error << " in " << __PRETTY_FUNCTION__ << endl;
-    listOk=true;
-  }
-  assert(glIsList(LList));
   glCallList(LList);
+  ColorsProxy *border = glGraph->getSuperGraph()->getProperty<ColorsProxy>("viewBorderColor");
+  glGraph->desactivateTexture();
+  Color c = border->getNodeValue(n);
+  //  setMaterial(c);
+  glLineWidth(2);
+  glDisable(GL_LIGHTING);
+  glColor3ub(c[0],c[1],c[2]);
+  glCallList(LList + 1);  
+  glEnable(GL_LIGHTING);
 }
 
 
 Coord CubeOutLined::getAnchor(const Coord & vector ) const {
   float x,y,z, fmax;
   vector.get(x,y,z);
-  fmax = ( fabsf(x) >? fabsf(y) ) >? fabsf(z);
+  fmax = std::max(std::max(fabsf(x), fabsf(y)), fabsf(z));
   if( fmax > 0.0f )
     return vector * (0.5f/fmax);
   else
@@ -144,3 +158,57 @@ void CubeOutLined::drawCube(GLenum type) {
   glVertex3f(-0.5f, -0.5f, -0.5f);
   glEnd();
 }
+void CubeOutLined::drawCubeSimple(GLenum type) {
+  /* front face */
+  glBegin(type);
+  glVertex3f(-0.5f, -0.5f, 0.5f); 
+  glVertex3f(0.5f, -0.5f, 0.5f);
+  glVertex3f(0.5f, 0.5f, 0.5f);
+  glVertex3f(-0.5f, 0.5f, 0.5f);
+  glEnd();
+  /* back face */
+  glBegin(type);
+  glVertex3f(-0.5f, -0.5f, -0.5f); 
+  glVertex3f(-0.5f, 0.5f, -0.5f);
+  glVertex3f(0.5f, 0.5f, -0.5f);
+  glVertex3f(0.5f, -0.5f, -0.5f);
+  glEnd();
+  /* right face */
+  glBegin(type);
+  glVertex3f(0.5f, -0.5f, -0.5f); 
+  glVertex3f(0.5f, 0.5f, -0.5f);
+  glVertex3f(0.5f, 0.5f, 0.5f);
+  glVertex3f(0.5f, -0.5f, 0.5f);
+  glEnd();
+  /* left face */
+  glBegin(type);
+  glVertex3f(-0.5f, -0.5f, 0.5f); 
+  glVertex3f(-0.5f, 0.5f, 0.5f);
+  glVertex3f(-0.5f, 0.5f, -0.5f);
+  glVertex3f(-0.5f, -0.5f, -0.5f);
+  glEnd();
+  /* top face */
+  glBegin(type);
+  glNormal3f(0.0f, 1.0f, 0.0f);
+  glTexCoord2f(1.0f, 0.0f);
+  glVertex3f(0.5f, 0.5f, 0.5f); 
+  glTexCoord2f(1.0f, 1.0f);
+  glVertex3f(0.5f, 0.5f, -0.5f);
+  glTexCoord2f(0.0f, 1.0f);
+  glVertex3f(-0.5f, 0.5f, -0.5f);
+  glTexCoord2f(0.0f, 0.0f);
+  glVertex3f(-0.5f, 0.5f, 0.5f);
+  glEnd();
+  /* bottom face */
+  glBegin(type);
+  glNormal3f(0.0f, -1.0f, 0.0f);
+  glTexCoord2f(1.0f, 0.0f);
+  glVertex3f(0.5f, -0.5f, -0.5f); 
+  glTexCoord2f(1.0f, 1.0f);
+  glVertex3f(0.5f, -0.5f, 0.5f);
+  glTexCoord2f(0.0f, 1.0f);
+  glVertex3f(-0.5f, -0.5f, 0.5f);
+  glTexCoord2f(0.0f, 0.0f);
+  glVertex3f(-0.5f, -0.5f, -0.5f);
+  glEnd();
+}
