@@ -29,6 +29,8 @@
 
 #include "TLPParser.h"
 
+#define TLP "tlp"
+#define TLP_VERSION 2.0
 #define NODES "nodes"
 #define EDGE "edge"
 #define CLUSTER "cluster"
@@ -54,6 +56,7 @@
 #define DISPLAYING "displaying"
 #define GLYPH "glyph"
 #define PLUGIN "plugin"
+#define ATTRIBUTES "attributes"
 
 using namespace std;
 //=================================================================================
@@ -63,169 +66,204 @@ struct TLPGraphBuilder:public TLPTrue {
   map<int,edge> edgeIndex;
   map<int,SuperGraph *> clusterIndex;
   DataSet *dataSet;
+  bool inTLP;
+  float version;
   
   TLPGraphBuilder(SuperGraph *superGraph, DataSet *dataSet): _superGraph(superGraph),
 							     dataSet(dataSet) {
     clusterIndex[0]=superGraph;
+    inTLP = false;
+    version = 0;
   }
 
   virtual ~TLPGraphBuilder(){
   }
+
+  bool addDouble(const double val) {
+    // only used to handle the version of tlp file format
+    if (!version) {
+      version = (float) val;
+      return version == TLP_VERSION;
+    }
+    return false;
+  }
   
   bool addNode(int id) {
     nodeIndex[id]=_superGraph->addNode();
     return true;
   }
-  bool addClusterNode(int id,int nodeId) {
-    clusterIndex[id]->addNode(nodeIndex[nodeId]);
-    return true;
-  }
-  bool addClusterEdge(int id,int edgeId)  {
-    clusterIndex[id]->addEdge(edgeIndex[edgeId]);
-    return true;
-  }
-  bool addEdge(int id,int idSource,int idTarget) {
-    edgeIndex[id]=_superGraph->addEdge(nodeIndex[idSource],nodeIndex[idTarget]);
-    return true;
-  }
-  bool setNodeValue(int nodeId, int clusterId, const string propertyType, const string propertyName, string value) {
-    //cerr << "set node value ....." ;
-    if (propertyType==METAGRAPH) {
-      char *endPtr=0;
-      const char *startPtr=value.c_str();
-      int result=strtol(startPtr,&endPtr,10);
-      if (endPtr==startPtr) return false;
-      if (clusterIndex.find(result)==clusterIndex.end()) return false;
-      if (result==0) 
-	clusterIndex[clusterId]->getLocalProperty<MetaGraphProxy>(propertyName)->setNodeValue(nodeIndex[nodeId],0);
-      else
-	clusterIndex[clusterId]->getLocalProperty<MetaGraphProxy>(propertyName)->setNodeValue(nodeIndex[nodeId],clusterIndex[result]);
+  bool addClusterNode(int id, int nodeId) {
+    if (_superGraph->isElement(nodeIndex[nodeId]) && clusterIndex[id]) {
+      clusterIndex[id]->addNode(nodeIndex[nodeId]);
       return true;
     }
-    if (propertyType==METRIC) 
-      return clusterIndex[clusterId]->getLocalProperty<MetricProxy>(propertyName)->setNodeStringValue( nodeIndex[nodeId], value );
-    if (propertyType==LAYOUT) 
-      return clusterIndex[clusterId]->getLocalProperty<LayoutProxy>(propertyName)->setNodeStringValue( nodeIndex[nodeId], value );
-    if (propertyType==SIZE) 
-      return clusterIndex[clusterId]->getLocalProperty<SizesProxy>(propertyName)->setNodeStringValue( nodeIndex[nodeId], value );
-    if (propertyType==COLOR) 
-      return clusterIndex[clusterId]->getLocalProperty<ColorsProxy>(propertyName)->setNodeStringValue( nodeIndex[nodeId], value );
-    if (propertyType==INT) 
-      return clusterIndex[clusterId]->getLocalProperty<IntProxy>(propertyName)->setNodeStringValue( nodeIndex[nodeId], value );
-    if (propertyType==BOOL) 
-      return clusterIndex[clusterId]->getLocalProperty<SelectionProxy>(propertyName)->setNodeStringValue( nodeIndex[nodeId], value );
-    if (propertyType==STRING) 
-      return clusterIndex[clusterId]->getLocalProperty<StringProxy>(propertyName)->setNodeStringValue( nodeIndex[nodeId], value );
+    return false;
+  }
+  bool addClusterEdge(int id, int edgeId)  {
+    if (_superGraph->isElement(edgeIndex[edgeId]) && clusterIndex[id]) {
+      clusterIndex[id]->addEdge(edgeIndex[edgeId]);
+      return true;
+    }
+    return true;
+  }
+  bool addEdge(int id, int idSource,int idTarget) {
+    if (_superGraph->isElement(nodeIndex[idSource]) && _superGraph->isElement(nodeIndex[idTarget])) {
+      edgeIndex[id]=_superGraph->addEdge(nodeIndex[idSource],nodeIndex[idTarget]);
+      return true;
+    }
+    return false;
+  }
+  bool setNodeValue(int nodeId, int clusterId, const string propertyType, const string propertyName, string value) {
+    if (_superGraph->isElement(nodeIndex[nodeId]) && clusterIndex[clusterId]) {
+      //cerr << "set node value ....." ;
+      if (propertyType==METAGRAPH) {
+	//      cerr << ".";
+	char *endPtr=0;
+	const char *startPtr=value.c_str();
+	int result=strtol(startPtr,&endPtr,10);
+	if (endPtr==startPtr) return false;
+	if (clusterIndex.find(result)==clusterIndex.end()) return false;
+	if (result==0) 
+	  clusterIndex[clusterId]->getLocalProperty<MetaGraphProxy>(propertyName)->setNodeValue(nodeIndex[nodeId],0);
+	else
+	  clusterIndex[clusterId]->getLocalProperty<MetaGraphProxy>(propertyName)->setNodeValue(nodeIndex[nodeId],clusterIndex[result]);
+	return true;
+      }
+      if (propertyType==METRIC) 
+	return clusterIndex[clusterId]->getLocalProperty<MetricProxy>(propertyName)->setNodeStringValue( nodeIndex[nodeId], value );
+      if (propertyType==LAYOUT) 
+	return clusterIndex[clusterId]->getLocalProperty<LayoutProxy>(propertyName)->setNodeStringValue( nodeIndex[nodeId], value );
+      if (propertyType==SIZE) 
+	return clusterIndex[clusterId]->getLocalProperty<SizesProxy>(propertyName)->setNodeStringValue( nodeIndex[nodeId], value );
+      if (propertyType==COLOR) 
+	return clusterIndex[clusterId]->getLocalProperty<ColorsProxy>(propertyName)->setNodeStringValue( nodeIndex[nodeId], value );
+      if (propertyType==INT) 
+	return clusterIndex[clusterId]->getLocalProperty<IntProxy>(propertyName)->setNodeStringValue( nodeIndex[nodeId], value );
+      if (propertyType==BOOL) 
+	return clusterIndex[clusterId]->getLocalProperty<SelectionProxy>(propertyName)->setNodeStringValue( nodeIndex[nodeId], value );
+      if (propertyType==STRING) 
+	return clusterIndex[clusterId]->getLocalProperty<StringProxy>(propertyName)->setNodeStringValue( nodeIndex[nodeId], value );
+    }
     return false;
     //cer << "..ok" << endl;
   }
   
   bool setEdgeValue(int edgeId, int clusterId, const string &propertyType, const string &propertyName, string value) {
-    //cerr << "setEdgeValue...." << "edge:" << edgeId << " cluster " << clusterId << " " << propertyName << " " << propertyType << " value=\""<< value<<"\"  ";
-    bool result=false;
+    if (_superGraph->isElement(edgeIndex[edgeId]) && clusterIndex[clusterId]) {
+      //cerr << "setEdgeValue...." << "edge:" << edgeId << " cluster " << clusterId << " " << propertyName << " " << propertyType << " value=\""<< value<<"\"  ";
+      bool result=false;
 
-    if (propertyType==METAGRAPH) {
-      char *endPtr=0;
-      const char *startPtr=value.c_str();
-      int result=strtol(startPtr,&endPtr,10);
-      if (endPtr==startPtr) return false;
-      if (clusterIndex.find(result)==clusterIndex.end()) return false;
-      if (result==0) 
-	clusterIndex[clusterId]->getLocalProperty<MetaGraphProxy>(propertyName)->setEdgeValue(edgeIndex[edgeId],0);
-      else
-	clusterIndex[clusterId]->getLocalProperty<MetaGraphProxy>(propertyName)->setEdgeValue(edgeIndex[edgeId],clusterIndex[result]);
-      return true;
+      if (propertyType==METAGRAPH) {
+	char *endPtr=0;
+	const char *startPtr=value.c_str();
+	int result=strtol(startPtr,&endPtr,10);
+	if (endPtr==startPtr) return false;
+	if (clusterIndex.find(result)==clusterIndex.end()) return false;
+	if (result==0) 
+	  clusterIndex[clusterId]->getLocalProperty<MetaGraphProxy>(propertyName)->setEdgeValue(edgeIndex[edgeId],0);
+	else
+	  clusterIndex[clusterId]->getLocalProperty<MetaGraphProxy>(propertyName)->setEdgeValue(edgeIndex[edgeId],clusterIndex[result]);
+	return true;
+      }
+      if (propertyType==METRIC) 
+	result= clusterIndex[clusterId]->getLocalProperty<MetricProxy>(propertyName)->setEdgeStringValue( edgeIndex[edgeId], value );
+      if (propertyType==LAYOUT) 
+	result= clusterIndex[clusterId]->getLocalProperty<LayoutProxy>(propertyName)->setEdgeStringValue( edgeIndex[edgeId], value );
+      if (propertyType==SIZE) 
+	result= clusterIndex[clusterId]->getLocalProperty<SizesProxy>(propertyName)->setEdgeStringValue( edgeIndex[edgeId], value );
+      if (propertyType==COLOR) 
+	result= clusterIndex[clusterId]->getLocalProperty<ColorsProxy>(propertyName)->setEdgeStringValue( edgeIndex[edgeId], value );
+      if (propertyType==INT) 
+	result= clusterIndex[clusterId]->getLocalProperty<IntProxy>(propertyName)->setEdgeStringValue( edgeIndex[edgeId], value );
+      if (propertyType==BOOL) 
+	result= clusterIndex[clusterId]->getLocalProperty<SelectionProxy>(propertyName)->setEdgeStringValue( edgeIndex[edgeId], value );
+      if (propertyType==STRING) 
+	result= clusterIndex[clusterId]->getLocalProperty<StringProxy>(propertyName)->setEdgeStringValue( edgeIndex[edgeId], value );
+      //cer<< "..ok result=" << result<< endl;
+      return result;
     }
-    if (propertyType==METRIC) 
-      result= clusterIndex[clusterId]->getLocalProperty<MetricProxy>(propertyName)->setEdgeStringValue( edgeIndex[edgeId], value );
-    if (propertyType==LAYOUT) 
-      result= clusterIndex[clusterId]->getLocalProperty<LayoutProxy>(propertyName)->setEdgeStringValue( edgeIndex[edgeId], value );
-    if (propertyType==SIZE) 
-      result= clusterIndex[clusterId]->getLocalProperty<SizesProxy>(propertyName)->setEdgeStringValue( edgeIndex[edgeId], value );
-    if (propertyType==COLOR) 
-      result= clusterIndex[clusterId]->getLocalProperty<ColorsProxy>(propertyName)->setEdgeStringValue( edgeIndex[edgeId], value );
-    if (propertyType==INT) 
-      result= clusterIndex[clusterId]->getLocalProperty<IntProxy>(propertyName)->setEdgeStringValue( edgeIndex[edgeId], value );
-    if (propertyType==BOOL) 
-      result= clusterIndex[clusterId]->getLocalProperty<SelectionProxy>(propertyName)->setEdgeStringValue( edgeIndex[edgeId], value );
-    if (propertyType==STRING) 
-      result= clusterIndex[clusterId]->getLocalProperty<StringProxy>(propertyName)->setEdgeStringValue( edgeIndex[edgeId], value );
-    //cer<< "..ok result=" << result<< endl;
-    return result;
+    return false;
   }
 
   bool setAllNodeValue(int clusterId, const string propertyType, const string propertyName, string value) {
-    //cerr << "set all node value ....." ;
-    if (propertyType==METAGRAPH) {
-      char *endPtr=0;
-      const char *startPtr=value.c_str();
-      int result=strtol(startPtr,&endPtr,10);
-      if (endPtr==startPtr) result =0; //return false;
-      if (clusterIndex.find(result)==clusterIndex.end()) return false;
-      if (result==0) 
-	clusterIndex[clusterId]->getLocalProperty<MetaGraphProxy>(propertyName)->setAllNodeValue(0);
-      else
-	clusterIndex[clusterId]->getLocalProperty<MetaGraphProxy>(propertyName)->setAllNodeValue(clusterIndex[result]);
-      return true;
+    if (clusterIndex[clusterId]) {
+      //cerr << "set all node value ....." ;
+      if (propertyType==METAGRAPH) {
+	char *endPtr=0;
+	const char *startPtr=value.c_str();
+	int result=strtol(startPtr,&endPtr,10);
+	if (endPtr==startPtr) result =0; //return false;
+	if (clusterIndex.find(result)==clusterIndex.end()) return false;
+	if (result==0) 
+	  clusterIndex[clusterId]->getLocalProperty<MetaGraphProxy>(propertyName)->setAllNodeValue(0);
+	else
+	  clusterIndex[clusterId]->getLocalProperty<MetaGraphProxy>(propertyName)->setAllNodeValue(clusterIndex[result]);
+	return true;
+      }
+      if (propertyType==METRIC) 
+	return clusterIndex[clusterId]->getLocalProperty<MetricProxy>(propertyName)->setAllNodeStringValue( value );
+      if (propertyType==LAYOUT) 
+	return clusterIndex[clusterId]->getLocalProperty<LayoutProxy>(propertyName)->setAllNodeStringValue( value );
+      if (propertyType==SIZE) 
+	return clusterIndex[clusterId]->getLocalProperty<SizesProxy>(propertyName)->setAllNodeStringValue( value );
+      if (propertyType==COLOR) 
+	return clusterIndex[clusterId]->getLocalProperty<ColorsProxy>(propertyName)->setAllNodeStringValue( value );
+      if (propertyType==INT) 
+	return clusterIndex[clusterId]->getLocalProperty<IntProxy>(propertyName)->setAllNodeStringValue( value );
+      if (propertyType==BOOL) 
+	return clusterIndex[clusterId]->getLocalProperty<SelectionProxy>(propertyName)->setAllNodeStringValue( value );
+      if (propertyType==STRING) 
+	return clusterIndex[clusterId]->getLocalProperty<StringProxy>(propertyName)->setAllNodeStringValue( value );
     }
-    if (propertyType==METRIC) 
-      return clusterIndex[clusterId]->getLocalProperty<MetricProxy>(propertyName)->setAllNodeStringValue( value );
-    if (propertyType==LAYOUT) 
-      return clusterIndex[clusterId]->getLocalProperty<LayoutProxy>(propertyName)->setAllNodeStringValue( value );
-    if (propertyType==SIZE) 
-      return clusterIndex[clusterId]->getLocalProperty<SizesProxy>(propertyName)->setAllNodeStringValue( value );
-    if (propertyType==COLOR) 
-      return clusterIndex[clusterId]->getLocalProperty<ColorsProxy>(propertyName)->setAllNodeStringValue( value );
-    if (propertyType==INT) 
-      return clusterIndex[clusterId]->getLocalProperty<IntProxy>(propertyName)->setAllNodeStringValue( value );
-    if (propertyType==BOOL) 
-      return clusterIndex[clusterId]->getLocalProperty<SelectionProxy>(propertyName)->setAllNodeStringValue( value );
-    if (propertyType==STRING) 
-      return clusterIndex[clusterId]->getLocalProperty<StringProxy>(propertyName)->setAllNodeStringValue( value );
     return false;
     //cer << "..ok" << endl;
   }
   bool setAllEdgeValue(int clusterId, const string &propertyType, const string &propertyName, string value) {
-    //cerr << "setAllEdgeValue.." << endl;
-    bool result=false;
+    if (clusterIndex[clusterId]) {
+      //cerr << "setAllEdgeValue.." << endl;
+      bool result=false;
 
-    if (propertyType==METAGRAPH) {
-      char *endPtr=0;
-      const char *startPtr=value.c_str();
-      int result=strtol(startPtr,&endPtr,10);
-      if (endPtr==startPtr) result = 0; //return false;
-      if (clusterIndex.find(result)==clusterIndex.end()) return false;
-      if (result==0)
-	clusterIndex[clusterId]->getLocalProperty<MetaGraphProxy>(propertyName)->setAllEdgeValue(0);
-      else
-	clusterIndex[clusterId]->getLocalProperty<MetaGraphProxy>(propertyName)->setAllEdgeValue(clusterIndex[result]);
-      return true;
+      if (propertyType==METAGRAPH) {
+	char *endPtr=0;
+	const char *startPtr=value.c_str();
+	int result=strtol(startPtr,&endPtr,10);
+	if (endPtr==startPtr) result = 0; //return false;
+	if (clusterIndex.find(result)==clusterIndex.end()) return false;
+	if (result==0)
+	  clusterIndex[clusterId]->getLocalProperty<MetaGraphProxy>(propertyName)->setAllEdgeValue(0);
+	else
+	  clusterIndex[clusterId]->getLocalProperty<MetaGraphProxy>(propertyName)->setAllEdgeValue(clusterIndex[result]);
+	return true;
+      }
+      if (propertyType==METRIC) 
+	result= clusterIndex[clusterId]->getLocalProperty<MetricProxy>(propertyName)->setAllEdgeStringValue( value );
+      if (propertyType==LAYOUT) 
+	result= clusterIndex[clusterId]->getLocalProperty<LayoutProxy>(propertyName)->setAllEdgeStringValue( value );
+      if (propertyType==SIZE) 
+	result= clusterIndex[clusterId]->getLocalProperty<SizesProxy>(propertyName)->setAllEdgeStringValue( value );
+      if (propertyType==COLOR) 
+	result= clusterIndex[clusterId]->getLocalProperty<ColorsProxy>(propertyName)->setAllEdgeStringValue( value );
+      if (propertyType==INT) 
+	result= clusterIndex[clusterId]->getLocalProperty<IntProxy>(propertyName)->setAllEdgeStringValue( value );
+      if (propertyType==BOOL) 
+	result= clusterIndex[clusterId]->getLocalProperty<SelectionProxy>(propertyName)->setAllEdgeStringValue( value );
+      if (propertyType==STRING) 
+	result= clusterIndex[clusterId]->getLocalProperty<StringProxy>(propertyName)->setAllEdgeStringValue( value );
+      //cer<< "..ok result=" << result<< endl;
+      return result;
     }
-    if (propertyType==METRIC) 
-      result= clusterIndex[clusterId]->getLocalProperty<MetricProxy>(propertyName)->setAllEdgeStringValue( value );
-    if (propertyType==LAYOUT) 
-      result= clusterIndex[clusterId]->getLocalProperty<LayoutProxy>(propertyName)->setAllEdgeStringValue( value );
-    if (propertyType==SIZE) 
-      result= clusterIndex[clusterId]->getLocalProperty<SizesProxy>(propertyName)->setAllEdgeStringValue( value );
-    if (propertyType==COLOR) 
-      result= clusterIndex[clusterId]->getLocalProperty<ColorsProxy>(propertyName)->setAllEdgeStringValue( value );
-    if (propertyType==INT) 
-      result= clusterIndex[clusterId]->getLocalProperty<IntProxy>(propertyName)->setAllEdgeStringValue( value );
-    if (propertyType==BOOL) 
-      result= clusterIndex[clusterId]->getLocalProperty<SelectionProxy>(propertyName)->setAllEdgeStringValue( value );
-    if (propertyType==STRING) 
-      result= clusterIndex[clusterId]->getLocalProperty<StringProxy>(propertyName)->setAllEdgeStringValue( value );
-    //cer<< "..ok result=" << result<< endl;
-    return result;
+    return false;
   }
   bool addCluster(int id, const string&name, int fatherId=0) {
-    SelectionProxy *selProxy=clusterIndex[fatherId]->getLocalProperty<SelectionProxy>("tmpSelection");
-    selProxy->setAllNodeValue(false);
-    selProxy->setAllEdgeValue(false);
-    clusterIndex[id]=clusterIndex[fatherId]->addSubGraph(selProxy);
-    clusterIndex[id]->setAttribute("name",name);
-    clusterIndex[fatherId]->delLocalProperty("tmpSelection");
-    return true;
+    if (clusterIndex[fatherId]) {
+      SelectionProxy selProxy(clusterIndex[fatherId]);
+      selProxy.setAllNodeValue(false);
+      selProxy.setAllEdgeValue(false);
+      clusterIndex[id] = clusterIndex[fatherId]->addSubGraph(&selProxy);
+      clusterIndex[id]->setAttribute("name", name);
+      return true;
+    }
+    return false;
   }
   bool addStruct(const string& structName,TLPBuilder*&newBuilder) ;
 };
@@ -262,23 +300,25 @@ struct TLPEdgeBuilder:public TLPFalse {
 //=================================================================================
 struct TLPClusterBuilder:public TLPFalse {
   TLPGraphBuilder *graphBuilder;
-  int clusterId,fatherId;
-  TLPClusterBuilder(TLPGraphBuilder *graphBuilder,int father=0):graphBuilder(graphBuilder),fatherId(father){}
+  int clusterId, fatherId;
+  TLPClusterBuilder(TLPGraphBuilder *graphBuilder, int father=0):graphBuilder(graphBuilder), fatherId(father){}
   bool addInt(const int id) {
-    clusterId=id;
+    clusterId = id;
     return true;
   }
   bool addString(const string &str) {
     return graphBuilder->addCluster(clusterId , str, fatherId);
   }
-  bool addStruct(const string& structName,TLPBuilder*&newBuilder);
+  bool addStruct(const string& structName, TLPBuilder*&newBuilder);
   bool addNode (int nodeId) {
     return graphBuilder->addClusterNode(clusterId,nodeId);
   }
   bool addEdge (int edgeId) {
     return graphBuilder->addClusterEdge(clusterId,edgeId);
   }
-  bool close(){return true;}
+  bool close(){
+    return true;
+  }
 };
 //=================================================================================
 struct TLPClusterNodeBuilder:public TLPFalse {
@@ -295,34 +335,44 @@ struct TLPClusterEdgeBuilder:public TLPFalse {
   bool close(){return true;}
 };
 //================================================================================
-struct TLPDisplayingBuilder: public TLPFalse {
+struct TLPDataSetBuilder: public TLPFalse {
   TLPGraphBuilder *graphBuilder;
   DataSet dataSet;
+  char* dataSetName;
   
-  TLPDisplayingBuilder(TLPGraphBuilder *graphBuilder):graphBuilder(graphBuilder){
-    graphBuilder->dataSet->get<DataSet>(DISPLAYING, dataSet);
+  TLPDataSetBuilder(TLPGraphBuilder *graphBuilder):graphBuilder(graphBuilder){
+    dataSetName = (char *) 0;
+  }
+  TLPDataSetBuilder(TLPGraphBuilder *graphBuilder, char* name):graphBuilder(graphBuilder){
+    dataSetName = name;
+    graphBuilder->dataSet->get(dataSetName, dataSet);
+  }
+  virtual ~TLPDataSetBuilder(){
   }
-  virtual ~TLPDisplayingBuilder(){}
   bool addStruct(const string& structName, TLPBuilder*&newBuilder);
   bool close(){
-    graphBuilder->dataSet->set(DISPLAYING, dataSet);
+    if (dataSetName)
+      graphBuilder->dataSet->set(dataSetName, dataSet);
     return true;
   }
 };
 //================================================================================
-struct TLPDisplayingPropertyBuilder : public TLPFalse
+struct TLPDataBuilder : public TLPFalse
 {
-  TLPDisplayingBuilder *displayingBuilder;
-  DataSet *data;
+  TLPDataSetBuilder *dataSetBuilder;
+  DataSet *dataSet;
   string type, prop;
   int token;
-  TLPDisplayingPropertyBuilder(TLPDisplayingBuilder *displayingBuilder, const string& type): displayingBuilder(displayingBuilder),
-											     data(&(displayingBuilder->dataSet)),
+  TLPDataBuilder(TLPDataSetBuilder *dataSetBuilder, const string& type): dataSetBuilder(dataSetBuilder),
 											     type(type), prop(""),
-											     token(0)
-  {}
+											     token(0) {
+    if (dataSetBuilder->dataSetName)
+      dataSet = &(dataSetBuilder->dataSet);
+    else
+      dataSet = &(dataSetBuilder->graphBuilder->_superGraph->getAttributes());
+  }
   
-  ~TLPDisplayingPropertyBuilder(){}
+  ~TLPDataBuilder(){}
   bool addString(const string &val) {
     switch(token++) {
     case 0: prop = val; break;
@@ -330,17 +380,19 @@ struct TLPDisplayingPropertyBuilder : public TLPFalse
       if (type==COLOR) {
 	Color c;
 	if ( ColorType::fromString(c,val) )
-		data->set(prop, c);
+		dataSet->set(prop, c);
 	else cerr << __PRETTY_FUNCTION__ << ": COLOR failed" << endl;
 	//else return false;
       }
       else if (type==COORD) {
 	Coord c;
 	if ( PointType::fromString(c,val) )
-		data->set(prop, c);
+		dataSet->set(prop, c);
 	else cerr << __PRETTY_FUNCTION__ << ": COORD failed" << endl;
 	//else return false;
       }
+      else if (type==STRING)
+	dataSet->set(prop, val);
       else {
 	cerr << __PRETTY_FUNCTION__ << ": TYPE = " << type << ", " << prop << " = " << val << endl;
 	return false;
@@ -352,7 +404,7 @@ struct TLPDisplayingPropertyBuilder : public TLPFalse
     return true;
   }
   bool addBool(const bool val) {
-    if ((type==BOOL) && (token++ == 1)) data->set(prop, val);
+    if ((type==BOOL) && (token++ == 1)) dataSet->set(prop, val);
     return true;
   }
   
@@ -360,20 +412,20 @@ struct TLPDisplayingPropertyBuilder : public TLPFalse
     if ((type==INT) && (token == 1)) {
       if (prop == "SupergraphId") {
 	int v;
-	if (displayingBuilder->graphBuilder->clusterIndex.find(val) != displayingBuilder->graphBuilder->clusterIndex.end()) {
-	  v=displayingBuilder->graphBuilder->clusterIndex[val]->getId();
-	  data->set<int>(prop, v);
+	if (dataSetBuilder->graphBuilder->clusterIndex.find(val) != dataSetBuilder->graphBuilder->clusterIndex.end()) {
+	  v=dataSetBuilder->graphBuilder->clusterIndex[val]->getId();
+	  dataSet->set<int>(prop, v);
 	}
 	else {
 	  //	  cerr << "Import TLP: Warning: no cluster #" << val << " defined." << endl;
 	}
       }
       else {
-	data->set<int>(prop, val);
+	dataSet->set<int>(prop, val);
       }
     }
     else if ((type==UINT) && (token == 1)) {
-      data->set<unsigned int>(prop, val);
+      dataSet->set<unsigned int>(prop, val);
     }
     token++;
     return true;
@@ -381,12 +433,12 @@ struct TLPDisplayingPropertyBuilder : public TLPFalse
   
   bool addDouble(const double val) {
     if ((type==DOUBLE) && (token == 1)) {
-      data->set<double>(prop, val);
+      dataSet->set<double>(prop, val);
       token++;
       return true;
     }
     else if ((type==FLOAT) && (token == 1)) {
-      data->set<float>(prop, (float) val);
+      dataSet->set<float>(prop, (float) val);
       token++;
       return true;
     }
@@ -395,7 +447,7 @@ struct TLPDisplayingPropertyBuilder : public TLPFalse
   bool close() {return (token==2);}
 };
 //=================================================================================
-bool TLPClusterBuilder::addStruct(const string& structName,TLPBuilder*&newBuilder)   { 
+bool TLPClusterBuilder::addStruct(const string& structName, TLPBuilder*&newBuilder)   { 
     if (structName==CLUSTERNODES) {
       newBuilder=new TLPClusterNodeBuilder(this);
     }
@@ -405,7 +457,7 @@ bool TLPClusterBuilder::addStruct(const string& structName,TLPBuilder*&newBuilde
       }
       else
 	if (structName==CLUSTER) {
-	  newBuilder=new TLPClusterBuilder(graphBuilder,clusterId);
+	  newBuilder = new TLPClusterBuilder(graphBuilder, clusterId);
 	}
 	else {
 	  newBuilder=new TLPFalse();
@@ -422,7 +474,7 @@ struct TLPPropertyBuilder:public TLPFalse {
   virtual ~TLPPropertyBuilder() {}
   TLPPropertyBuilder(TLPGraphBuilder *graphBuilder):graphBuilder(graphBuilder),typeOk(false),nameOk(false){}
   bool addInt(const int id)  {
-    clusterId=id;
+    clusterId = id;
     return true;
   }
   bool addString(const string &str)
@@ -510,7 +562,11 @@ bool TLPPropertyBuilder::addStruct(const string& structName,TLPBuilder*&newBuild
 }
 //=================================================================================
 bool TLPGraphBuilder::addStruct(const string& structName,TLPBuilder*&newBuilder) {
-  if (structName==NODES) {
+  if (structName==TLP) {
+    inTLP = true;
+    newBuilder=this;
+  }
+  else if (structName==NODES) {
     newBuilder=new TLPNodeBuilder(this);
   }
   else if (structName==EDGE) {
@@ -523,18 +579,20 @@ bool TLPGraphBuilder::addStruct(const string& structName,TLPBuilder*&newBuilder)
     newBuilder=new TLPPropertyBuilder(this);
   }
   else if (structName==DISPLAYING) {
-    newBuilder=new TLPDisplayingBuilder(this);
+    newBuilder=new TLPDataSetBuilder(this, DISPLAYING);
+  } else if (structName==ATTRIBUTES) {
+    newBuilder=new TLPDataSetBuilder(this);
   }
   else
     newBuilder=new TLPTrue();
   return true;
 }
 //================================================================================
-bool TLPDisplayingBuilder::addStruct(const string& structName,TLPBuilder*&newBuilder) {
+bool TLPDataSetBuilder::addStruct(const string& structName,TLPBuilder*&newBuilder) {
   if (structName==COORD || structName==COLOR || structName==BOOL ||
       structName==INT || structName==UINT || structName==FLOAT ||
-      structName==DOUBLE) {
-    newBuilder=new TLPDisplayingPropertyBuilder(this, structName);
+      structName==DOUBLE || structName==STRING) {
+    newBuilder= new TLPDataBuilder(this, structName);
   }
   else
     newBuilder= new TLPTrue();
@@ -556,13 +614,13 @@ namespace {
 struct TLPImport:public ImportModule {
 public:
   TLPImport(ClusterContext context):ImportModule(context) {
-    addParameter<string>("filename",paramHelp[0]);
+    addParameter<string>("file::filename", paramHelp[0]);
     addParameter<DataSet>(DISPLAYING);
   }
   ~TLPImport(){}
   bool import(const string &dummy) {
     string filename;
-    dataSet->get<string>("filename", filename);
+    dataSet->get<string>("file::filename", filename);
     struct stat infoEntry;
     #ifdef _WIN32
     stat(filename.c_str(),&infoEntry);
@@ -580,9 +638,11 @@ public:
     
     TLPParser<false> myParser(*input, new TLPGraphBuilder(superGraph, dataSet),pluginProgress,size);
     bool result = myParser.parse();
+    if (!result)
+      std::cerr << pluginProgress->getError() << std::endl;
     delete input;
     return result;
   }
 };
 /*@}*/
-IMPORTPLUGIN(TLPImport,"tlp","Auber","16/02/2001","0","0","1");
+IMPORTPLUGINOFGROUP(TLPImport,"tlp","Auber","16/02/2001","0","0","1","File");
