@@ -1,7 +1,7 @@
 #include <assert.h>
 #include "Random.h"
 
-LAYOUTPLUGIN(Random,"Random","David Auber","01/12/1999","Ok","0","1");
+LAYOUTPLUGINOFGROUP(Random,"Random","David Auber","01/12/1999","Ok","0","1","Basic");
 
 using namespace std;
 
