@@ -9,7 +9,11 @@ using namespace std;
 /** \addtogroup layout */
 /*@{*/
 /// TreeRadial.cpp - An implementation of radial drawing of trees.
-struct TreeRadial:public Layout {
+/** 
+ *
+ **/
+class TreeRadial:public Layout {
+public:
   MetricProxy *leaves;
 
   TreeRadial(const PropertyContext &context):Layout(context) {
@@ -77,4 +81,4 @@ struct TreeRadial:public Layout {
   void reset() {}
 };
 /*@}*/
-LAYOUTPLUGIN(TreeRadial,"Tree Radial","David Auber","03/03/2001","Ok","0","1");
+LAYOUTPLUGINOFGROUP(TreeRadial,"Tree Radial","David Auber","03/03/2001","Ok","0","1","Tree");
