@@ -16,34 +16,28 @@ struct LR {
 /** This plugin is an implementation of the hierarchical tree layout
  *  algorithm first published as:
  *
- *  E.M. Reingold and J.S. Tilford,
- *  "Tidier Drawings of Trees",
- *  "IEEE Transactions on Software Engineering"
- *  pages "223--228"
- *  1981
+ *  E.M. Reingold and J.S. Tilford, \n
+ *  "Tidier Drawings of Trees", \n
+ *  "IEEE Transactions on Software Engineering" \n
+ *  pages "223--228" \n
+ *  1981 \n
  *
- *  HISTORY:
+ *  <b>HISTORY</b>
  *
- *  21/02/2000 Verson 0.0.1: Initial release
+ *  - 21/02/2000 Verson 0.0.1: Initial release
+ *  - 06/11/2002 Verson 0.0.2: Documentation and code clean up
+ *  - 06/01/2005 Verson 0.0.3: Code refactoring, management of : orienetation, parameters
  *
- *  06/11/2002 Verson 0.0.2: Documentation and code clean up
- *
- *  NOTES:
- *
- *  This algorithm only works on trees.
- *  Let n be the number of nodes, the algorithm complexity is in O(n).
+ *  \note This algorithm only works on trees.\n
+ *  Let n be the number of nodes, the algorithm complexity is in O(n).\n
  *  It extends the original Reingold and Tilford by providing managment
- *  of different node size and different edge length.
+ *  of different node size and different edge length. \n \n
+ *  The algorithm use the (Size)"viewSize" property for element size and the
+ *  (int)"treeEdgeLength" for the edge length.
  *
- *  The algortihm use the (Size)"viewSize" property for element size and the
- *  (int)"treeEdgeLength" for the edge length. The property (int)"treeOrder"
- *  can be used to change the embedding of the tree.
+ *  \author David Auber LaBRI, University Bordeaux I France, Email : auber@tulip-software.org
  *
- *  AUTHOR:
- *
- *  David Auber University Bordeaux I France: Email:auber@tulip-software.org
- *
- *  LICENCE:
+ *  <b>LICENCE</b>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by  
@@ -55,7 +49,7 @@ class TreeReingoldAndTilfordExtended:public Layout {
 public:
   TreeReingoldAndTilfordExtended(const PropertyContext &);
   ~TreeReingoldAndTilfordExtended();
-  bool run();
+                      bool run();
   bool check(std::string &);
   void reset();
 
@@ -65,9 +59,15 @@ private:
   double  calcDecal(const std::list<LR>& , const std::list<LR>&);
   std::list<LR>* mergeLRList(std::list<LR>*,std::list<LR>*,double decal);
   std::list<LR>* TreePlace(node, stdext::hash_map<node,double>*);
-  void TreeLevelSizing(node ,std::map<int,double> &,int );
+  void TreeLevelSizing(node ,std::map<int,double> &,int , std::map<node,int> &levels);
+
   SizesProxy *sizesProxy;
-  IntProxy *lengthMetric;
+  IntProxy   *lengthMetric;
+  bool ortho;
+  bool useLength;
+  std::string orientation;
+  float spacing;
+  float nodeSpacing;
 };
 /*@}*/
 #endif
