@@ -1,9 +1,9 @@
-#include <qinputdialog.h>
 #include <tulip/MetricProxy.h>
+#include <tulip/ForEach.h>
 #include <deque>
 #include "ClusterMetric.h"
 
-METRICPLUGIN(ClusterMetric,"Cluster","David Auber","26/02/2003","Beta","0","2");
+METRICPLUGINOFGROUP(ClusterMetric,"Cluster","David Auber","26/02/2003","Beta","0","2","Graph");
 
 using namespace std;
 
@@ -16,20 +16,14 @@ namespace {
     HTML_HELP_DEF( "default", "1" ) \
     HTML_HELP_BODY() \
     "This parameter defines the maximal depth of a computed cluster." \
-    HTML_HELP_CLOSE(),
+    HTML_HELP_CLOSE()
   };
 }
-
+//=================================================
 ClusterMetric::ClusterMetric(const PropertyContext &context):Metric(context) {
   addParameter<unsigned int>("depth",paramHelp[0],"1");
 }
-
-ClusterMetric::~ClusterMetric() {}
-
-double ClusterMetric::getEdgeValue(const edge e ) {
-  return 0;
-}
-
+//=================================================
 void ClusterMetric::buildSubGraph(node n,node startNode,set<node> &selected,unsigned int depth) {
   deque<node> fifo;
   SuperGraph * graph = superGraph;
@@ -57,7 +51,17 @@ void ClusterMetric::buildSubGraph(node n,node startNode,set<node> &selected,unsi
     }
   }
 }
-
+//=================================================
+double ClusterMetric::getEdgeValue(const edge e ) {
+  node src = superGraph->source(e);
+  node tgt = superGraph->target(e);
+  double v1 = metricProxy->getNodeValue(src);
+  double v2 = metricProxy->getNodeValue(tgt);
+  if (v1*v1 + v2*v2 > 0)
+    return 1.-fabs(v1 - v2)/sqrt(v1*v1 + v2*v2);
+  return 0.;
+}
+//=================================================
 double ClusterMetric::getNodeValue(const node n ) {
   set<node> reachableNodes;
   buildSubGraph(n,n,reachableNodes,maxDepth);
@@ -77,14 +81,24 @@ double ClusterMetric::getNodeValue(const node n ) {
   }
   
   double nNode= reachableNodes.size(); //$|N_v|$
-  if (reachableNodes.size()>1)
-    return (double)nbEdge/(nNode*(nNode-1)); //$e(N_v)/(\frac{k*(k-1)}{2}}$
+  if (reachableNodes.size()>1) {
+    double result = double(nbEdge)/(nNode*(nNode-1));
+    return result; //$e(N_v)/(\frac{k*(k-1)}{2}}$
+  }
   else
     return 0;
 }
-
+//=================================================
 bool ClusterMetric::run() {
+  cerr << __PRETTY_FUNCTION__ << endl;
   maxDepth=1;
   if (dataSet!=0) dataSet->get("depth",maxDepth);
+  node n;
+  forEach(n, superGraph->getNodes())
+    metricProxy->setNodeValue(n, getNodeValue(n));
+  edge e;
+  forEach(e, superGraph->getEdges())
+    metricProxy->setEdgeValue(e, getEdgeValue(e));
   return true;
 }
+//=================================================
