@@ -1,43 +1,34 @@
-#if (__GNUC__ < 3)
-#include <hash_map>
-#else
-#include <ext/hash_map>
-#endif
 
+#include <tulip/ForEach.h>
 #include "ConnectedComponent.h"
 
 
-METRICPLUGIN(ConnectedComponent,"Connected Component","David Auber","01/07/2002","Alpha","0","1");
+METRICPLUGINOFGROUP(ConnectedComponent,"Connected Component","David Auber","01/07/2002","Alpha","0","1","Component");
 
 ConnectedComponent::ConnectedComponent(const PropertyContext &context):Metric(context) {}
-
+//======================================================
 ConnectedComponent::~ConnectedComponent(){}
-
-void ConnectedComponent::dfs(node n, stdext::hash_map<node,bool> &flag,double value){
-  if (flag.find(n)!=flag.end()) return;
-  flag[n]=true;
+//======================================================
+void ConnectedComponent::dfs(node n, MutableContainer<bool> &flag,double value){
+  if (flag.get(n.id)) return;
+  flag.set(n.id, true);
   metricProxy->setNodeValue(n,value);
-  Iterator<node> *itN=superGraph->getInOutNodes(n);
-  for (;itN->hasNext();) {
-    node itn=itN->next();
+  node itn;
+  forEach(itn, superGraph->getInOutNodes(n))
     dfs(itn,flag,value);
-  }delete itN;
 }
-
-
+//======================================================
 bool ConnectedComponent::run() {
-  stdext::hash_map<node,bool> flag;
-
+  MutableContainer<bool> flag;
+  flag.setAll(false);
   double curComponent=0;
-  Iterator<node> *itN=superGraph->getNodes();
-  while (itN->hasNext()) {
-    node itn=itN->next();
-    if (flag.find(itn)==flag.end()) {
+  node itn;
+  forEach(itn, superGraph->getNodes()) {
+    if (!flag.get(itn.id)) {
       dfs(itn,flag,curComponent);
       curComponent++;
     }
-  } delete itN;
-
+  }
   Iterator<edge> *itE=superGraph->getEdges();
   while (itE->hasNext()) {
     edge ite=itE->next();
@@ -51,7 +42,7 @@ bool ConnectedComponent::run() {
 
   return true;
 }
-
+//======================================================
 
 
 
