@@ -4,28 +4,24 @@
 
 #include <tulip/TulipPlugin.h>
 
+template<typename T>
+class MutableConatainer;
 
 /** \addtogroup selection */
 /*@{*/
-///
 
+/// This selection plugins enables to find a subgraph of G that is acyclic.
+/**
+ * This selection plugins enables to find a subgraph of G that is acyclic.
+ *
+ *  \author David Auber, LaBRI University Bordeaux I France: 
+ *   auber@tulip-software.org
+ */
 class SpanningDagSelection:public Selection { 
 
 public:
-  ///
   SpanningDagSelection(const PropertyContext &);
-  ///
-  ~SpanningDagSelection();
-  ///
   bool run();
-  ///
-  bool check(std::string &);
-  ///
-  void reset();
-
-private :
-  ///
-  void dfsAcyclicTest(const node &,SelectionProxy *,SelectionProxy *);
 };
 /*@}*/
 #endif
