@@ -1,12 +1,34 @@
 //-*-c++-*-
 #include <tulip/TulipPlugin.h>
+#include <tulip/ForEach.h>
 #include <cmath>
-///
+
+/** \addtogroup size */
+/*@{*/
+/// AutoSizes.cpp - Compute size in order to prevent node-node overlapping
+/**
+ * This plug-ins compute size of nodes and edges such that, node-node overlapping do not exists (if it is possible).
+ * and sizes of edges are proportional to size of nodes.
+ *
+ *  \author David Auber University Bordeaux I France: Email:auber@tulip-software.org
+ */
 class AutoSizes:public Sizes
 { 
 public:
   AutoSizes(const PropertyContext &context):Sizes(context){}
-  ~AutoSizes(){}
+
+  bool run() {
+    node n;
+    forEach(n,superGraph->getNodes())
+      sizesProxy->setNodeValue(n, getNodeValue(n));
+    edge e;
+    forEach(e,superGraph->getEdges())
+      sizesProxy->setEdgeValue(e, getEdgeValue(e));
+    return true;
+  }
+
+
+private:
   Size getNodeValue(const node n) {
     LayoutProxy *entryLayout=superGraph->getProperty<LayoutProxy>("viewLayout");
 
@@ -43,8 +65,8 @@ public:
   }
 
   Size getEdgeValue(const edge e) {
-    Size s=sizesProxy->getNodeValue(superGraph->source(e));
-    Size t=sizesProxy->getNodeValue(superGraph->target(e));
+    Size s = sizesProxy->getNodeValue(superGraph->source(e));
+    Size t = sizesProxy->getNodeValue(superGraph->target(e));
     Coord tmp(s.getW(),s.getH(),s.getD());
     Coord tmp2(t.getW(),t.getH(),t.getD());
     float sizes=tmp.norm();
@@ -53,16 +75,5 @@ public:
   }
 
 };
+/*@}*/
 SIZESPLUGIN(AutoSizes,"Auto_sizing","Auber","04/05/2001","0","0","1")
-
-
-
-
-
-
-
-
-
-
-
-
