@@ -2,8 +2,8 @@
 #include    "FTOutlineGlyph.h"
 
 
-FTGLOutlineFont::FTGLOutlineFont( const char* fontname)
-:   FTFont( fontname)
+FTGLOutlineFont::FTGLOutlineFont( const char* fontFilePath)
+:   FTFont( fontFilePath)
 {}
 
 
@@ -18,11 +18,11 @@ FTGLOutlineFont::~FTGLOutlineFont()
 
 FTGlyph* FTGLOutlineFont::MakeGlyph( unsigned int g)
 {
-    FT_Glyph* ftGlyph = face.Glyph( g, FT_LOAD_NO_HINTING);
+    FT_GlyphSlot ftGlyph = face.Glyph( g, FT_LOAD_NO_HINTING);
 
     if( ftGlyph)
     {
-        FTOutlineGlyph* tempGlyph = new FTOutlineGlyph( *ftGlyph);
+        FTOutlineGlyph* tempGlyph = new FTOutlineGlyph( ftGlyph, useDisplayLists);
         return tempGlyph;
     }
 
